Japanese subtitles - kitsunekko.net

Sort by: File↑ Date

.hack G.U | 2 years
3-gatsu no Lion | 3 years
4 cut hero | 5 months
4-nin wa Sorezore Uso wo Tsuku | 8 months
05 GOLDEN BOY | 6 months
5-tou ni Naritai | 1 decade
07-Ghost | 2 years
7SEEDS | 3 years
7th Time Loop: The Villainess Enjoys a Carefree Life Married to Her Worst Enemy! | 2 weeks
11eyes | 1 year
16bit Sensation: Another Layer | 3 months
30-sai made Doutei dato Mahoutsukai ni Nareru Rashii | 3 weeks
86 - Eighty Six | 10 months
91 Days | 6 years
100-man no Inochi no Ue ni Ore wa Tatteiru | 2 years
180 Byou de Kimi no Mimi o Shiawase ni Dekiru ka? | 2 years
</script> | 4 days
< script> | 4 days
A.I.C.O. Incarnation | 6 years
Aa! Megami-sama! | 8 years
Absolute Duo | 5 years
ACCA | 3 years
Accel World | 5 years
Acchi Kocchi | 1 decade
Ace of Diamond Act II | 3 years
Ace Of Diamond | 2 years
A Channel | 5 years
Adachi to Shimamura | 3 years
adtqv5 | 1 month
Afro Samurai | 2 years
Aggretsuko | 1 year
Aharen-san wa Hakarenai | 8 months
Ahiru no sora | 8 months
Ahiru no Sora | 3 years
Aho Girl | 6 years
Aikatsu! | 5 months
Aikatsu Friends | 6 years
Aikatsu on Parade! | 4 years
Aikatsu Planet! | 3 years
Ai no Utagoe wo Kikasete | 9 months
Air | 4 years
Ai Shite Knight | 6 years
Ajin | 1 year
Ajin S2 | 5 years
Akagami no Shirayukihime | 3 years
Akage no Anne | 5 years
Akame ga Kill | 10 months
Akane-iro ni Somaru Saka | 1 year
Akanesasu Shoujo | 5 years
Akatsuki no Yona | 11 months
Akebi-chan no Sailor-fuku | 1 year
Akiba Maid War | 7 months
Akira | 5 months
Akudama Drive | 2 years
Akuma-kun | 1 decade
Akumaizer 3 | 9 years
Akuma no Riddle | 1 year
Aku no Hana | 3 years
Akuyaku Reijou Level 99: Watashi wa Ura-Boss desu ga Maou dewa Arimasen | 3 weeks
Aldnoah Zero | 6 years
A Letter to Momo | 3 years
Alice Gear Aegis Expansion | 10 months
Alice in Borderland | 3 months
Alice in Deadly School | 3 years
Amaama to Inazuma | 3 years
Amagami SS | 5 years
Amagami SS Plus | 6 years
Amagi Brilliant Park | 1 year
Ame o Tsugeru Hyouryuu Danchi | 11 months
Ame wo Tsugeru Hyouryuu Danchi | 4 months
Amnesia | 1 decade
Android Kikaider | 9 years
Ane Koi | 3 months
Angel Beats | 1 year
Angel Heart | 3 years
Angolmois: Genkou Kassenki | 4 years
Animation Seisaku Shinkou Kuromi-chan | 4 years
Animation Seisaku Shinkou Kuromi-chan 2 | 4 years
Anime Mirai 2014 | 1 decade
Anohana The Flower We Saw That Day | 10 months
Ano Natsu de Matteru | 4 years
Another | 2 years
Ant-man and Wasp | 11 months
Ao Ashi | 1 year
Ao Haru Ride | 2 years
Aoharu x Kikanjuu | 8 years
Aoi Blink | 9 years
Aoi Hana | 3 years
Aoki Hagane no Arpeggio | 5 years
Ao No Exorcist | 1 year
Ao no Kanata no Four Rhythm | 7 years
Ao no Orchestra | 6 months
Aoyama Goushou Tanpenshuu | 4 years
Appare-Ranman! | 2 years
Appleseed | 4 years
Aquarion Evol | 1 decade
Araburu Kisetsu no Otome-domo yo | 4 years
Arakawa Under the Bridge | 4 years
Arakawa Under the Bridge 2 | 4 years
Arashi no Yoru ni | 1 year
Arashi no Yoru ni Himitsu no Tomodachi | 9 years
Argonavis from BanG Dream! | 2 years
ARIA The ANIMATION | 2 years
ARIA the AVVENIRE | 5 years
Arifureta Shokugyou de Sekai Saikyou | 1 year
Arknights: Prelude to Dawn | 8 months
Arslan Senki 2 | 7 years
Arslan Senki | 2 years
Ars no Kyojuu | 1 year
Asagao to Kase-san | 2 years
Ashita He Free Kick | 9 years
Ashita No Joe | 3 years
Ashita No Joe 2 | 11 months
Asobi Asobase | 7 months
Assassination Classroom | 2 years
Assault Lily Bouquet | 8 months
Astro Boy - Tetsuwan Atom 2003 | 6 months
Astro Note | 5 hours
Asura The Movie | 1 decade
Atarashii Joushi wa Do Tennen | 3 months
Atashin'chi | 6 months
Atom the Beginning | 6 years
Attack No. 1 | 5 years
Aura Battler Dunbine | 5 years
Avataro Sentai Donbrothers | 4 months
Avengers Assemble | 7 years
Ayaka | 7 months
Ayakashi Triangle | 6 months
Aya to Majo | 1 month
Azumanga Daioh | 6 months
B: The Beginning | 6 years
B: The Beginning Succession | 3 years
ba | 5 months
Babel II | 5 years
baby | 5 months
baby | 5 months
Babylon | 2 years
Baby Steps | 3 years
Baccano! | 1 year
Back Street Girls: Gokudolls | 5 years
Baja no Studio | 4 years
Baka to Test to Shoukanjuu | 4 years
Bakemonogatari | 10 months
Bakemono no Ko | 4 months
Baki (2018) | 3 years
Baki (2020) | 3 years
Bakuage Sentai Boonboomger | 1 month
Bakugan Battle Brawlers Gundalian Invaders | 5 years
Bakujou Sentai Bunbunger | 6 days
Bakuman | 5 months
Bakuon!! | 7 years
Bakuryuu Sentai Abaranger | 9 years
Bakushou Red Beach! | 8 years
BakuTech! Bakugan | 1 decade
Bakuten | 2 years
Ballroom e Youkoso | 4 years
Banana Fish | 2 years
BanG Dream! | 10 months
BanG Dream! It's MyGO!!!!! | 2 months
Barakamon | 2 years
Baraou no Souretsu | 1 year
BARTENDER Kami no Glass | 2 days
Basilisk | 5 years
Bastard!! Ankoku no Hakaishin (2022) | 1 year
Batman Ninja | 5 years
Battle Athletes Victory | 3 years
Battle Athletes DaiUndoukai ReSTART | 2 years
Battle Fever J | 2 years
Battle Spirits Brave | 1 decade
Battle Spirits Burning Soul | 8 years
Battle Spirits Double Drive | 7 years
Battle Spirits Heroes | 1 decade
Battle Spirits Sword Eyes | 1 decade
Battle Spirits Sword Eyes Gekitouden | 1 decade
Bayonetta: Bloody Fate | 1 decade
Beastars | 2 years
BEASTARS S2 | 3 years
Beast Saga | 1 decade
Beatless | 4 years
Beauty and the Beast | 3 months
Beck: Mongolian Chop Squad | 1 year
Beelzebub | 3 years
Belle (Ryuu to Sobakasu no Hime) | 1 year
BEM | 4 years
Benriya Saitou-san, Isekai ni Iku | 1 year
BEN TO | 1 year
Berserk | 5 years
Berserk Ougon Jidai Hen | 4 years
Betterman | 5 years
Beyblade Burst Chouzetsu | 2 years
Beyblade Burst Gachi | 2 years
Beyblade X | 22 hours
Beyblade Burst | 3 years
Beyblade Burst God | 2 years
Big Fish and Begonia | 5 years
Big Order | 8 years
Binbou Shimai Monogatari | 1 decade
Binzume Yousei Bottle Fairy | 5 years
Biohazard Degeneration | 1 decade
BIRDIE WING Season 2 | 8 months
Bishoujo Senshi Sailor Moon Crystal | 2 years
Bishounen Tanteidan | 4 weeks
Black Bullet | 5 years
Black Clover | 4 months
Black Fox (Blackfox) | 4 years
Black Jack Final | 1 decade
Black Lagoon | 8 months
Black Jack | 2 years
Black Rock Shooter | 9 years
Blade x Soul | 9 years
BLAME! | 5 years
Blazing Transfer Students | 6 years
Bleach | 8 months
Bleach: Sennen Kessen-hen | 5 months
BLEND-S | 2 months
Blood+ | 1 year
Blood-C | 3 years
Blood-C The Movie - The Last Dark | 5 years
Blood The Last Vampire | 1 decade
Blue Archive the Animation | 5 days
Blue Comet SPT Layzner | 5 years
Blue Giant | 4 months
Blue Lock | 1 week
Blue Reflection Ray | 2 years
Blue Submarine No. 6 | 1 decade
Blue Thermal | 7 months
Blue Period | 2 years
Blue Reflection Ray | 1 year
BNA (Brand New Animal) | 3 years
Bocchi the Rock! | 2 months
Bofuri | 2 years
Boku, unmei no hito desu | 6 years
Boku dake ga Inai Machi | 3 years
Boku no Kanojo ga Majime Sugiru Shojo Bitch na Ken | 2 years
Boku no Kokoro no Yabai Yatsu | 1 month
Boku no Kokoro no Yabai Yatsu S2 | 2 weeks
Boku no Kokoro no Yabai Yatsu season2 | 3 weeks
Boku no Son Gokuu | 9 years
Bokura ga Ita (We Were There) | 2 years
Bokurano | 5 years
Bokura no Ameiro Protocol | 3 months
Bokura no Nanokakan Sensou (BDRip 1080p Movie) | 2 years
Bokura Wa Minna Kawaisou | 2 years
Bokusatsu Tenshi Dokuro-chan | 11 months
Bokutachi no Remake | 6 months
Bokutachi wa Benkyou ga Dekinai | 2 months
Boku Dake Ga Inai Machi | 5 months
Boku No Hero Academia | 5 hours
Boku Wa Tomodachi Ga Sukunai | 4 years
Boku Wa Tomodachi Ga Sukunai Next | 4 years
Boogiepop wa Warawanai (2019) | 4 years
Boogiepop wa Warawanai - Boogiepop Phantom | 2 years
boruto | 7 months
Boruto Naruto Next Generations | 7 months
Bottom tier tomozaki | 4 months
Boukensha ni Naritai to Miyako ni Deteitta Musume ga S-Rank ni Natteta | 3 months
Boukyaku Battery | 3 days
Boushoku no Berserk | 4 months
bqmB'GHrQNw<'">aOtbyB | 2 months
bqmB..,)'()(," | 2 months
bqmB | 2 months
Brave 10 | 1 decade
Brave Story | 5 years
Brave Witches | 5 years
Brave Beats | 8 years
Brave Raideen | 1 decade
Brothers Conflict | 9 years
Brush Up Life | 3 months
Btooom! | 10 months
Bubble | 1 year
Bubblegum Crisis | 8 years
Bucchigiri?! | 2 weeks
Buddha Saitan - The Rebirth of Buddha | 1 decade
Buddy Complex | 6 years
Buddy Daddies | 9 months
Bullbuster | 3 months
Bungaku Shoujo | 1 decade
Bungo Stray Dogs Wan | 10 months
Bungou Stray Dogs | 6 months
Burn the witch | 9 months
Busou Renkin | 5 years
Busou Shoujo Machiavellianism | 5 years
Busou Shinki | 1 decade
Buta no Liver wa Kanetsu Shiro | 3 months
Byousoku 5 Centimeter | 4 years
C - The Money of Soul and Possibility Control | 3 years
Caligula | 5 years
Campione! | 5 years
Cannon Busters | 4 years
Cap Kakumei Bottleman | 3 years
Captain Harlock (2013) | 1 decade
Captain Tsubasa Season 2: Junior Youth-hen | 6 days
Cardcaptor Sakura | 4 years
Cardcaptor Sakura Clear Card Hen | 3 years
Cardcaptor Sakura Clear Card Hen Prologue Sakura to Futatsu no Kuma | 6 years
Cardfight!! Vanguard: will+Dress | 8 months
CARDFIGHT!! VANGUARD Divinez | 1 week
Cardfight!! Vanguard | 3 years
Cardfight!! Vanguard Asia Circuit Hen | 3 years
Cardfight!! Vanguard G | 3 years
Cardfight!! Vanguard G NEXT | 3 years
Cardfight!! Vanguard Legion Mate Hen | 3 years
Cardfight!! Vanguard Link Joker Hen | 3 years
Carole & Tuesday | 4 years
Castlevania | 3 years
Cbhz'GoPCBJ<'">ZxxbNM | 1 month
Cbhz((,((',.," | 1 month
Cbhz | 1 month
CENCOROLL | 4 years
Chainsaw Man | 8 months
Chaos;Head | 1 decade
chara | 2 months
Charlotte | 1 year
Cheburashka The Movie 2010 | 9 years
Chi's Sweet Home | 9 years
Chiba Pedal | 7 years
Chibi Maruko-chan (1990) | 2 months
Chibi Maruko-chan | 6 days
Chihayafuru | 1 year
Chihayafuru S2 | 1 year
Chihayafuru S3 | 1 year
Chio-chan no Tsuugakuro | 5 years
Chiyu Mahou no Machigatta Tsukaikata | 3 weeks
Chobits | 1 year
Chocchan Monogatari | 4 years
Choujinki Metalder | 8 years
Choujin Barom 1 | 3 years
Choujin Bibyun | 9 years
Choujuu Sentai Liveman | 1 decade
Choukou Senshi Shanzerion | 8 years
Chousei Kantai Sazer-X | 5 years
Chouseishin Gransazer | 5 years
Chouyaku Hakunin Isshu - Utakoi | 1 decade
Chou Soku Henkei Gyrozetter | 1 decade
Chuukan Kanriroku Tonegawa | 3 years
Chuunibyou demo Koi ga Shitai! | 1 year
Chuunibyou demo Koi ga Shitai! Ren | 4 months
Chuunibyou demo Koi ga Shitai! The Movie | 1 decade
Chuunibyou demo Koi ga Shitai! The Movie 2 | 2 years
Cider no You ni Kotoba ga Wakiagaru | 2 years
Citrus | 6 years
City Hunter | 5 years
City Hunter: Ai to Shukumei no Magnum | 1 week
City Hunter The Movie 2019 - Shinjuku Private Eyes (BDrip PGS Sup ) | 4 years
City Hunter | 4 years
Clannad | 5 months
Clannad Movie | 1 year
Clannad After Story | 5 months
ClassicaLoid | 5 years
Classroom Crisis | 8 years
Claymore | 2 years
Clockwork Planet | 6 years
Cobra The Animation | 9 years
CodeBreaker | 6 years
Code Geass: Fukkatsu no Lelouch (Lelouch of the Re;surrection) | 1 year
Code Geass Boukoku no Akito | 4 years
Code Geass Lelouch Of The Rebellion | 2 years
Code Geass Lelouch Of The Rebellion R2 | 2 years
Colorful | 3 months
cool doji danshi | 11 months
Cop Craft | 4 years
Coppelion | 5 years
Corpse Party | 9 years
Cowboy Bebop | 10 months
Crayon Shin-chan | 1 week
Cross Ange Tenshi to Ryuu no Rondo | 3 years
Cross Fight B-Daman | 1 decade
Cross Fight B-Daman eS | 1 decade
Cross Game | 5 years
CUE! | 5 months
Cyberpunk - Edgerunners | 1 year
Cyborg 009 | 5 years
D-Frag! | 4 years
D4DJ All Mix | 11 months
Dagashi Kashi | 3 years
Dai Sentai Goggle V | 1 week
Daishizen no Majuu Bagi | 9 years
Dakara Watashi wa Oshimashita | 1 year
Danball Senki | 1 decade
Danball Senki W | 1 decade
Danball Senki Wars | 3 years
Dance Dance Danseur | 1 year
Danchi Tomoo | 3 years
Danganronpa Kibou no Gakuen to Zetsubou no Koukousei The Animation | 3 years
DanMachi | 3 years
Danshi Koukousei no Nichijou | 4 years
Dantalian no Shoka | 1 decade
Dareka no Manazashi | 1 decade
Darker Than Black Ryuusei No Gemini | 1 decade
Darker Than Black | 6 years
Dark Gathering | 4 months
DARLING in the FRANXX | 3 years
Darwin's Game | 3 years
Date a Live | 2 weeks
Date a Live V | 2 days
Da Wang Rao Ming | 9 months
DAYS | 2 years
Deadman Wonderland | 10 months
Dead Mount Death Play | 3 months
Death March kara Hajimaru Isekai Kyousoukyoku | 5 years
Death Note | 3 days
Death Parade | 6 months
Death Note | 5 months
Deatte 5-byou de Battle | 2 years
Debiruman | 8 years
Deca-Dence | 3 years
dekiru | 3 months
Dekiru Neko wa Kyou mo Yuuutsu | 5 months
Dekisokonai to Yobareta Moto Eiyuu | 4 days
Dekoboko Majo no Oyako Jijou | 3 months
Delicious Party Pretty Cure | 9 months
Demi-chan wa Kataritai | 7 months
Demon Slayer | 1 year
Demon Slayer : Movie Hashira | 2 weeks
Dennou Coil | 1 year
Denpa Onna To Seishun Otoko | 1 decade
Denpa Teki na Kanojo (Electromagnetic Girlfriend) | 3 years
Denpa Kyoushi | 3 years
Densetsu no Yuusha no Densetsu | 9 years
Denshi Sentai Denjiman | 3 weeks
Detecive | 6 months
Detective Conan | 10 hours
Devilman Crybaby | 10 months
Devil May Cry | 1 year
Devils Line | 5 years
Devil Survivor 2 The Animation | 3 years
Diabolik Lovers | 2 years
Diabolik Lovers More, Blood | 3 years
Dies irae | 4 years
Di Gi Charat | 1 year
Digimon Adventure | 3 years
Digimon Adventure: (Reboot) | 2 years
Digimon Adventure Tri. | 5 years
Digimon Ghost Game | 1 year
Digimon Universe Appli Monsters | 3 years
Digimon Xros Wars | 1 decade
Disc Wars Avengers | 3 years
Dive!! | 3 years
Dog Signal | 3 months
Do It Yourself!! | 1 year
Doki Doki! PreCure | 3 years
Dokonjou Gaeru | 5 years
Domestic na Kanojo | 8 months
Donten ni Warau | 2 years
Donten ni Warau Gaiden | 4 years
Doraemon | 1 week
Doraemon the Movie 39 Nobita's Chronicle of the Moon Exploration | 4 years
Doraemon the Movie 2011 Remake: Nobita and the New Steel Troops ~Winged Angels~ | 2 years
Doraemon the Movie: Nobita's Treasure Island | 5 years
Dorei-ku The Animation | 5 years
Dorohedoro | 7 months
Dororo | 2 years
Dosanko Gal wa Namara Menkoi | 3 weeks
Double Decker! Doug & Kirill | 3 years
Doubutsu No Mori | 8 years
Doubutsu Sentai Zyuohger | 3 years
Doukoku no Nightmare | 9 years
Doukyonin wa Hiza, Tokidoki, Atama no Ue. | 2 years
doukyusei | 3 years
Dounika Naru Hibi | 3 years
Downtown no Gaki no Tsukai ya Arahende!! | 3 years
Dr. Stone | 4 months
Dragon, Ie wo Kau. | 2 years
Dragon ball | 4 months
Dragon Ball Movie and TV Special | 1 month
Dragon Ball Super: Super Hero | 5 months
Dragon Ball Super Broly | 2 weeks
Dragon Ball Z: Kami to Kami (Battle of Gods) | 1 decade
Dragon Ball Z Fukkatsu no F (Resurrection F) | 1 year
Dragon Quest - Yuusha Abel Densetsu | 3 years
Dragon Quest: Dai no Daibouken (2020) | 1 year
Dragon Quest: The Adventure of Dai | 3 years
Dragon Quest Dai no Daibouken (1991) | 3 years
Dragon Quest Your Story | 3 years
Dragon Ball | 2 weeks
Dragon Ball GT | 3 years
Dragon Ball Kai | 1 week
Dragon Ball Super | 9 months
Dragon Ball Z | 7 months
DRAMAtical Murder | 3 years
Drifters | 4 years
drop | 5 months
Duel Masters | 1 decade
Duel Masters Victory | 1 decade
Duel Masters Victory V | 3 years
Duel Masters Victory V3 | 3 years
Duel Masters VS | 3 years
Duel Masters VSR | 3 years
Duel Masters VSRF | 3 years
Dumbbell Nan Kilo Moteru? | 3 years
Dungeon Meshi | 2 days
Dungeon ni Deai o Motomeru no wa Machigatte Iru Darouka | 1 year
Dungeon ni Deai o Motomeru no wa Machigatte Iru Darouka Gaiden: Sword Oratoria | 5 years
Durarara!! | 5 years
Durarara!!x2 Ketsu | 3 years
Durarara!!x2 Shou | 3 years
Durarara!!x2 Ten | 2 years
D Cide Traumerei the Animation | 2 years
eCeE'LNlsDt<'">pHIDRJ | 2 months
eCeE).,(('".(( | 2 months
eCeE | 2 months
Eden | 2 years
edens zero | 1 year
Edens Zero 2nd Season | 6 months
Edomae Elf | 10 months
ef - a tale of memories | 1 decade
Egao | 9 years
Eien no 831 | 2 years
Eiga Daisuki Pompo-san | 2 years
Eikoku Ikka, Nihon o Taberu | 3 years
Eiyuu-ou, Bu wo Kiwameru Tame Tenseisu: Soshite, Sekai Saikyou no Minarai Kishi | 1 year
Eiyuu Kyoushitsu | 6 months
Eizouken ni wa Te wo Dasu na! | 10 months
Elfen Lied | 2 years
Encouragement of Climb: Next Summit | 1 year
Enen no Shouboutai | 1 year
Engage Kiss | 1 year
Engine Sentai Go-Onger | 3 years
Ensemble Stars! | 3 years
Eromanga Sensei | 5 years
Escaflowne | 1 decade
Escha Chron | 6 years
Esper Mami | 6 years
Eureka Seven AO | 5 years
Eureka Seven | 4 years
EVE no Jikan | 4 years
EycH | 4 months
Eyeshield 21 | 1 year
Fairy Gone | 4 years
Fairy Tail The Movie | 5 years
Fairy Tail | 6 months
Fairy Tail Best! | 3 years
FAIRY TAIL S3E | 4 years
Fate | 6 months
Fate Apocrypha | 1 year
Fate Grand Order First Order | 7 years
Fate Grand Order MOONLIGHT LOSTROOM | 5 years
Fate Kaleid Liner Prisma Illya | 3 years
Fate Kaleid Liner Prisma Illya 3rei!! | 5 years
Fate Kaleid Liner Prisma Illya Zwei! | 3 years
Fate Stay Night | 5 years
Fate Stay Night Heaven's Feel | 6 months
Fate Stay Night Unlimited Blade Works 2014 | 3 years
Fate Stay Night Unlimited Blade Works Movie | 4 years
Fate Zero | 2 years
Fate EXTRA Last Encore | 3 years
Fate Grand Order: Zettai Majuu Sensen Babylonia | 4 years
Fei Ren Zai | 6 months
Final Fantasy VII Advent Children | 3 months
Final Fantasy XV Brotherhood | 7 years
Final Fantasy XV Kingsglaive | 7 years
First Love - Episode 2 | 3 months
First Love | 3 months
First Love Episode 2 | 3 months
FLAG | 1 decade
FLCL | 10 months
Flying Witch | 2 years
Fortune Favors Lady Nikuko | 1 year
Fractale | 1 decade
Fragtime | 3 years
Free! | 7 months
Free! Dive to the Future | 3 years
Free! Eternal Summer | 3 years
Free! Starting Days | 5 years
Free! Take Your Marks | 2 years
Freedom | 5 years
Fresh PreCure! | 5 years
Friends - Mononoke Shima no Naki | 1 decade
From Up On Poppy Hill | 1 decade
Fruits Basket (2019) | 2 years
Fruits Baskets | 5 years
Fugou Keiji: Balance:Unlimited | 3 years
Fukigen na Mononokean | 3 years
Fukumenkei Noise | 3 years
Fullmetal Alchemist - The Sacred Star Of Milos | 1 decade
Fullmetal Alchemist | 2 years
Full Metal Panic! Invisible Victory | 3 years
Fullmetal Alchemist Brotherhood | 2 years
Full Metal Panic! | 2 years
Full Metal Panic Fumoffu | 3 years
Full Metal Panic The Second Raid | 3 years
Fumetsu no Anata e | 3 months
Fune wo Amu | 2 years
Furusato Saisei Nippon no Mukashibanashi | 8 years
Fuse - Teppou Musume no Torimonochou | 1 decade
Futari Wa Pretty Cure | 1 year
Futari Wa Pretty Cure Max Heart | 3 years
Futari Wa Pretty Cure Splash Star | 3 years
Futsuu No Joshikousei Ga Locodol Yattemita | 3 years
Future Card Buddyfight | 3 years
Future Card Buddyfight 100 | 3 years
Future Card Buddyfight DDD | 3 years
Future War 198X Nen | 1 decade
Ga-Rei Zero | 1 decade
Gabriel Dropout | 5 years
Gaikotsu Kishi-sama, Tadaima Isekai e Odekakechuu | 1 year
Gaikotsu Shotenin Honda-san | 5 years
Gaist Crusher | 9 years
Gake no Ue no Ponyo | 3 years
Gakkou Gurashi! | 5 years
Gakuen Toshi Asterisk | 3 years
Galilei Donna | 1 decade
Gamers! | 5 years
Gangsta | 6 years
Gankutsuou | 7 months
Ganso Tensai Bakabon | 5 years
Gantz | 5 years
Garo | 2 days
Garo Makai Senki | 3 years
Garo Yami wo Terasu Mono | 3 years
GATE Jieitai Kanochi nite, Kaku Tatakaeri | 3 years
Gauche the Cellist | 3 years
Ged Senki | 3 years
GeGeGe no Kitaro | 4 years
Gekai Elise | 3 weeks
Gekidol | 11 months
Gekijouban Bishoujo Senshi Sailor Moon Eternal | 2 years
Gekijouban Fate Grand Order Shinsei Entaku Ryouiki Camelot | 2 years
Gekijouban Hibike! Euphonium ~Chikai no Finale~ | 10 months
Gekijouban High School Fleet | 3 years
Gekijouban Mahouka Koukou no Rettousei Hoshi o Yobu Shoujo | 6 years
Gekijouban Violet Evergarden | 1 month
Gekijouban Wakaokami wa Shougakusei! | 5 years
Gekijou Soushuuhen Code Geass Hangyaku no Lelouch | 5 years
Gekkan Shoujo Nozaki-kun | 3 years
Genesis Of Aquarion | 1 decade
Genji Monogatari Sennenki | 9 years
Genjitsu Shugi Yuusha no Oukoku Saikenki (How a Realist Hero Rebuilt the Kingdom) | 5 months
Genseishin Justirisers | 5 years
Genshiken Nidaime | 6 years
Getter Robo Arc | 2 years
Getter Robo | 1 decade
Getter Robot Go | 9 years
Ghost in the Shell | 4 months
Ghost in the Shell 2: Innocence | 4 months
Ghost in the Shell Arise | 8 months
Ghost in the Shell New Movie | 8 months
Ghost in the Shell SAC 2045 | 3 years
Ghost In The Shell Stand Alone Complex | 1 year
Ghost In The Shell Stand Alone Complex 2nd GIG | 10 months
Ghost Sweeper Mikami | 9 years
Giant Robo The Day the Earth Stood Still | 5 years
Giant Killing | 5 years
Ginban Kaleidoscope | 1 decade
Ginga Nagareboshi Gin | 5 years
Ginga Tetsudou 999 | 5 years
Ginga Tetsudou no Yoru | 2 years
Ginga E Kick-Off | 1 decade
Gingitsune | 2 years
Gintama' Enchousen | 1 decade
Gintama | 9 months
Gintama 2 Live action Rules Are Made To Be Broken (2018) | 2 years
Gin No Saji | 7 months
Giovanni no Shima | 9 years
Girlish Number | 2 years
Girls' Frontline | 2 years
GIRLS BAND CRY | 1 week
Girls und Panzer | 4 years
Girls und Panzer das Finale | 3 years
Girls und Panzer der Film | 2 years
Given | 8 months
Glass no Hana to Kowasu Sekai - Garakowa | 5 years
Glass no Hana to Kowasu Sekai | 8 years
Gleipnir | 2 years
Go! Princess Precure Go! Go!! Gouka 3-hontate!!! | 5 years
Go! Anpanman | 8 years
Go! Princess PreCure | 5 years
Goblin Slayer | 3 months
Gochuumon wa Usagi Desuka | 4 weeks
Gochuumon wa Usagi Desuka S2 | 4 weeks
Gochuumon wa Usagi Desuka S3 Bloom | 4 weeks
God Eater | 6 years
Godzilla: Kaijuu Wakusei | 4 years
Godzilla S.P | 2 years
GoGo Sentai Boukenger Resynced | 5 months
GoGo Sentai Boukenger | 5 years
gokukoku no brynhildr | 5 months
Gokushufudou | 1 year
Gokyoudai Monogatari | 1 decade
GOLDEN BOY | 6 months
Golden Kamuy | 9 months
Golden Time | 3 months
Golgo 13 | 2 years
GON | 8 years
Gosick | 4 years
Gotoubun No Hanayome | 3 months
GRANBELM | 4 years
Granblue Fantasy The Animation | 5 years
Grand blue | 7 months
Gravity Daze The Animation Ouverture | 7 years
Great Pretender | 3 years
Great Mazinger | 1 decade
GRIDMAN UNIVERSE | 4 months
Grimms Notes The Animation | 5 years
Grisaia no Kajitsu | 5 years
GTO (anime) | 10 months
GTO 1998 (Drama) | 1 year
Gugure! Kokkuri-san | 7 years
Guilty Crown | 6 years
Guin Saga | 1 decade
Gundam Seed | 5 years
Gundam Seed Destiny | 5 years
Gundam Build Fighters | 1 decade
Gundam Build Fighters Try | 7 years
Gundam G No Reconguista | 9 years
Gunjou no Fanfare | 1 year
Gunjou no Magmel | 4 years
Gunma-chan | 9 months
Guskou Budori no Denki | 1 decade
Gyakkyou Burai Kaiji | 2 years
Gyakkyou Burai Kaiji Hakairoku-hen | 2 years
Gyakusatsu Kikan GENOCIDAL ORGAN | 5 years
Gyakuten Sekai no Denchi Shoujo | 2 years
Gyakuten Saiban | 2 years
Gyakuten Saiban S02 | 2 years
Gyokou no Nikuko-chan | 9 months
Hachi-nan tte, Sore wa Nai deshou! | 10 months
Hachimitsu to Clover | 4 years
Hachimitsu to Clover II | 4 years
Hagehiro | 3 months
Haibane Renmei | 2 months
Haikyuu!! | 2 weeks
Haikyuu!! S3 | 4 months
Haikyuu!! S4 | 4 months
Haikyuu!! Second Season | 1 month
Hai to Gensou no Grimgar | 7 months
Haiyore! Nyaruko-san | 9 years
Haiyore! Nyaruko-san W | 5 years
Hajime No Ippo | 2 years
Hajimete no Gal | 4 years
Hajime No Ippo New Challenger | 3 years
Hakata Tonkotsu Ramens | 5 years
Hakkenden - Touhou Hakken Ibun | 9 years
Hakozume: Kouban Joshi no Gyakushuu | 2 years
Hakubo | 4 years
Hakumei no Tsubasa | 3 years
Hakumei to Mikochi | 2 years
Hakyuu Houshin Engi | 5 years
Hal | 8 years
Hamatora | 1 decade
Hametsu no Oukoku | 3 months
Hanamonogatari | 3 months
Hananoi-kun to Koi no Yamai | 2 days
Hanasakeru Seishounen | 1 decade
Hanasaku Iroha | 2 months
Hana to Alice Satsujin Jiken | 4 years
Hanayamata | 9 years
Hana Yori Dango | 2 years
Hanbun no Tsuki ga Noboru Sora | 1 decade
Handa-kun | 7 years
Hanebado! | 5 years
Hanma Baki - Son of Ogre (2021) | 2 years
Hannin no Hanzawa-san | 1 year
Hanyou no yashahime | 2 years
Hanyou no Yashahime | 1 year
Hanzawa Naoki | 8 years
HappinessCharge PreCure! | 5 years
Harmonie | 7 months
Harmony | 5 years
Hataraku Maou-sama! | 6 months
Hataraku Saibou!! | 2 years
Hataraku Saibou | 1 year
Hataraku Saibou Black | 3 years
Hatsukoi Monster | 7 years
Hayabusa | 2 weeks
Hayate no Gotoku!! | 9 years
Healin' Good Precure | 4 years
Healin' Good Precure | 3 years
Heart Catch PreCure! | 5 years
Heavy Object | 5 years
Heidi, Girl Of The Alps | 6 years
Heike Monogatari | 2 years
Heion Sedai no Idaten-tachi | 9 months
Heisei Tanuki Gassen Ponpoko | 3 years
Helck | 4 months
HELLO WORLD | 4 years
Hellsing | 4 years
Hell Teacher Nube | 5 years
Henjin no Salad Bowl | 1 day
Hentai Ouji to Warawanai Neko | 1 decade
Heroic Age | 1 decade
Heroman | 3 years
Hero Mask | 4 years
Hero Bank | 9 years
Hetalia Axis Powers | 1 decade
Hetalia The World Twinkle | 8 years
Heya Camp | 3 weeks
HEYBOT | 5 years
hi | 3 months
Hiatari Ryoukou | 6 years
Hibike! Euphonium | 10 months
Hibike! Euphonium 2 | 10 months
Hibike! Euphonium 3 | 6 days
Hibike! Euphonium ~Ensemble Contest~ | 1 month
Hibike Euphonium - Chikai no Finale (BD 1080p FLAC) PGS Movie | 9 months
Hibike Euphonium S03 | 6 days
Hidamari Sketch | 6 years
Hidamari Sketch X Hoshimittsu | 1 decade
Hidamari Sketch x Honeycomb | 8 years
Hidan no Aria AA | 8 years
Hidan No Aria | 9 years
Higashi no Eden | 2 years
Higeki no Genkyou to Naru Saikyou Gedou Last Boss Joou wa Tami no Tame ni Tsukushimasu | 1 month
Hige wo Soru. Soshite Joshi Ksei wo Hirou | 2 years
High Card | 3 months
Highschool DxD New | 1 decade
High School Fleet | 3 years
Highschool of the Dead | 4 years
High School Star Musical | 3 years
High School Star Musical S2 | 3 years
High School Star Musical S3 | 3 years
High Score Girl | 1 year
HIGHSPEED Etoile | 4 days
HIGHSPEED toile | 2 weeks
Higurashi no Naku Koro ni | 4 years
HIGURASHI NO NAKU KORO NI | 3 years
Higurashi no Naku Koro ni Gou | 2 years
Hiiro no Kakera | 1 decade
Hikari no Ou | 3 months
Hikaru no Go | 2 years
Hikikomari Kyuuketsuki no Monmon | 2 months
Himesama "Goumon" no Jikan desu | 3 weeks
Himesama Goumon no Jikan desu | 4 weeks
Hime Chen! Lilpri | 1 decade
Himitsu no AiPri | 6 days
Himitsu x Senshi Phantomirage | 5 years
Himitsu Sentai Goranger | 5 years
Himouto! Umaru-chan | 3 years
Hinako Note | 5 years
Hinamatsuri | 5 years
Hinomaruzumou - Hinomaru Sumo | 4 years
Hirogaru Sky! Pretty Cure | 2 months
Hirune-hime Shiranai Watashi no Monogatari | 3 weeks
Hirune Hime: | 3 weeks
Hisone to Masotan - Dragon Pilot | 5 years
Hitoribocchi no Marumaru Seikatsu | 10 months
Hiyokoi | 1 decade
Hokuto No Ken | 3 years
Honey Lemon Soda | 1 year
Honzuki no Gekokujou | 2 years
Hoozuki no Reitetsu 2 | 3 years
Hoozuki No Reitetsu | 3 years
Horimiya | 4 months
Horimiya: Piece | 4 months
Hoshiai no Sora | 2 years
Hoshikuzu Telepath | 1 month
Hoshi no Koe | 4 months
Hoshi no Samidare | 1 year
Hoshi wo Ou Kodomo | 4 years
Hotarubi no Mori e | 8 years
Hotaru No Haka | 4 years
Hottarake no Shima: Haruka to Mahou no Kagami | 1 decade
Houhokekyo Tonari no Yamada-kun | 3 years
Houkago no Pleiades | 3 years
Houkago Shounen Hanako-kun | 5 months
Houkago Teibou Nisshi | 2 years
Hourou Musuko | 6 years
Houseki No Kuni | 1 week
Housekishou Richard-shi no Nazo Kantei | 4 years
Howl's Moving Castle | 8 months
How Not to Summon a Demon Lord Omega | 2 years
How to Eliminate My Teacher - Sensei wo Kesu Houteishiki | 2 years
https: kitsunekko.net dirlist.php?dir=subtitles%2Fjapanese%2F | 6 months
Hugtto! Precure Futari wa Precure - All Stars Memories Movie | 4 years
HuGtto! PreCure | 3 years
Hula Fulla Dance | 9 months
HUNTER X HUNTER | 10 months
Hyakka Ryouran Samurai Girls | 1 decade
Hyakujuu Sentai Gaoranger | 3 years
Hybrid Child | 8 years
Hyouge Mono | 3 years
Hyouka | 2 years
Hyouken no Majutsushi ga Sekai wo Suberu | 1 year
Hypnosis Mic: Division Rap Battle - Rhyme Anima | 5 months
Ichiban Ushiro no Daimaou | 1 decade
Ichigo 100% | 2 years
Ichigo Mashimaro | 3 years
Ichigo Mashimaro Encore | 9 years
Ichigo Mashimaro OVA | 9 years
ID-0 | 6 years
ID:Invaded | 4 years
IDOLiSH7 | 2 months
Idolmaster Cinderella Girls U149 | 5 months
Idol x Warrior Miracle Tunes! | 5 years
Idoly Pride | 1 year
Idol Master | 1 decade
I Have Inherited the Host | 3 weeks
Ijiranaide Nagatorosan | 9 months
Ijiranaide Nagatorosan 2nd Attack | 9 months
Ikebukuro West Gate Park | 2 years
Ikoku Meiro no Croisee The Animation | 1 decade
Imaizumin Chi wa Douyara Gal no Tamariba ni Natteru Rashii | 7 months
Inazuma Eleven: Ares no Tenbin | 5 years
Inazuma Eleven: Orion no Kokuin | 4 years
Inazuma Eleven | 4 years
Inazuma Eleven GO | 1 decade
Inazuma Eleven GO Chrono Stone | 4 years
Inazuma Eleven GO Galaxy | 1 decade
Infinite Dendrogram | 3 years
Infinite Stratos | 5 years
Ingress | 5 years
Ingress the Animation | 5 years
Initial D Extra Stage | 11 months
Initial D Fifth Stage | 4 months
Initial D Final Stage | 4 months
Initial D First Stage | 4 months
Initial D Fourth Stage | 4 months
Initial D Legend | 4 months
Initial D Second Stage | 4 months
Initial D Third Stage | 11 months
Inu-Oh | 1 year
Inukami! | 5 years
Inu ni Nattara Suki na Hito ni Hirowareta. | 9 months
Inu to Hasami wa Tsukaiyou | 1 decade
InuYasha | 3 years
Inuyashiki | 3 years
Inu X Boku SS | 5 years
Iriya no Sora, UFO no Natsu | 1 decade
Irozuku Sekai no Ashita kara | 4 years
Isekai Cheat Magician | 4 years
Isekai de Cheat Skill wo Te ni Shita Ore wa, Genjitsu Sekai wo mo Musou Suru: Level Up wa Jinsei wo Kaeta | 8 months
Isekai de Mofumofu Nadenade Suru Tame ni Ganbattemasu. | 3 weeks
Isekai Maou to Shoukan Shoujo no Dorei Majutsu | 3 years
Isekai Maou to Shoukan Shoujo no Dorei Majutsu Omega | 2 years
Isekai Nonbiri Nouka | 1 year
Isekai Ojisan | 9 months
Isekai One Turn Kill Neesan | 9 months
Isekai Quartet | 4 years
Isekai Shokudou 2 | 2 years
Isekai Shoukan wa Nidome desu | 2 weeks
Isekai wa Smartphone to Tomo ni. | 10 months
Isekai Yakkyoku | 1 year
Isekai Maou To Shoukan Shoujo No Dorei Majutsu Omega | 2 years
Ishura | 3 weeks
Island | 5 years
Isshuukan Friends | 5 years
Itai no wa Iya nano de Bougyoryoku ni Kyokufuri Shitai to Omoimasu. | 11 months
Iwagou Mitsuaki no Sekai Neko Aruki | 8 years
Iya na Kao Sarenagara Opantsu Misete Moraitai | 4 years
J.A.K.Q. Dengekitai | 8 years
Jahy-sama wa Kujikenai! | 9 months
JAKQ Dengekitai | 3 years
Jaku-Chara Tomozaki-kun | 3 weeks
Jaku-Chara Tomozaki-kun season2 | 3 weeks
Japanese Anime Classic Collection | 1 decade
Japan Sinks: 2020 | 1 year
Jarinko Chie (Downtown Story) (1981) | 5 years
Jewelpet Happiness | 1 decade
Jewelpet Kira Deco! | 1 decade
Jewelpet Magical Change | 8 years
Jewelpet Sunshine | 1 decade
Jibaku Shounen Hanako-kun | 6 months
Jidou Hanbaiki ni Umarekawatta Ore wa Meikyuu wo Samayou | 7 months
Jigokuraku | 2 months
Jigoku Shoujo | 8 years
Jii-san Baa-san Wakagaeru | 6 days
Jijou wo Shiranai Tenkousei ga Guigui Kuru | 1 year
Jin | 4 years
Jin Roh The Wolf Brigade | 1 decade
Jinrui wa Suitai Shimashita | 2 years
Jitsu wa Ore, Saikyou deshita? | 1 month
JoJo no Kimyou na Bouken | 11 months
JoJo no Kimyou na Bouken: Diamond wa Kudakenai | 4 months
JoJo no Kimyou na Bouken: Ougon no Kaze (Golden Wind) | 4 months
JoJo no Kimyou na Bouken: Stardust Crusaders - Egypt Hen | 4 months
JoJo no Kimyou na Bouken: Stardust Crusaders | 4 months
JoJo no Kimyou na Bouken: Stone Ocean | 6 months
Joker Game | 5 years
Jormungand | 5 years
Josee to Tora to Sakana-tachi | 1 year
Joshikousei no Mudazukai | 9 months
Joshiraku | 1 decade
Joujuu Senjin!! Mushibugyou | 1 decade
Joukamachi No Dandelion | 7 years
Jujutsu Kaisen | 3 months
Jujutsu Kaisen 0 | 5 months
Jujutsu Kaisen 2nd Season | 2 months
Jujutsu kaisen season2 | 4 months
Jungle Taitei | 9 years
Junjou Romantica | 8 years
Junjou Romantica 2 | 8 years
Junjou Romantica 3 | 7 years
Junjou Romantica OAD | 8 years
Junod | 9 years
Just Because! | 5 years
Juuden Sentai Kyouryuuger | 8 years
Juuken Sentai Gekiranger | 5 years
Juuou Mujin No Fafnir | 9 years
Juusenshi Gulkeeva | 5 years
Juusen Battle Monsuno | 1 decade
Juushinki Pandora - Last Hope | 5 years
K-ON! | 1 year
k-on | 7 months
K | 5 years
Kabukibu | 5 years
Kabukichou Sherlock | 4 years
Kagami no Kojou | 8 months
Kageki Shoujo | 4 months
Kage no Jitsuryokusha ni Naritakute! (The Eminence in Shadow) | 3 months
Kagewani | 7 years
Kagewani Shou | 7 years
Kagihime Monogatari Eikyuu Alice Rondo | 1 decade
Kaguya-sama wa Kokurasetai - Tensai-tachi no Renai Zunousen | 6 months
Kaguya Hime no Monogatari | 2 years
Kaiba | 5 years
Kaibutsu Oujo | 1 decade
Kaichou wa Maid-sama | 2 years
Kaidan Restaurant | 4 years
Kaii to Otome to Kamigakushi | 1 week
Kaii to Otome to Kamikakushi | 3 days
Kaijin Kaihatsu-bu no Kuroitsu-san | 1 year
Kaijuu 8-gou | 6 days
Kaijuu Girls (Kuro) Ultra Kaijuu Gijinka Keikaku | 4 years
Kaijuu no Kodomo | 3 months
Kaiko sareta Ankoku Heishi (30-dai) no Slow na Second Life | 11 months
Kaitou Saint Tail | 4 years
Kaitou Sentai Lupinranger VS Keisatsu Sentai Patranger | 4 years
Kaizoku Sentai Gokaiger | 1 year
Kakegurui | 3 years
Kakegurui 2nd Season | 3 years
Kakegurui Twin | 1 year
Kakkou no Iinazuke | 9 months
Kakurenbo | 2 months
Kakushigoto | 1 year
Kamen Rider BLACK SUN | 1 year
Kamen Rider The First | 5 years
Kamen Rider Zi-O | 5 years
Kamen Sentai Gorider | 5 years
Kamen Rider | 7 years
Kamen Rider 555 | 1 decade
Kamen Rider Agito | 1 year
Kamen Rider Black | 8 years
Kamen Rider Black RX | 1 decade
Kamen Rider Blade | 3 years
Kamen Rider Build | 4 years
Kamen Rider Decade | 1 decade
Kamen Rider Den-O | 8 years
Kamen Rider Drive | 4 years
Kamen Rider Ex-Aid | 4 years
Kamen Rider Fourze | 1 year
Kamen Rider Gaim | 3 years
Kamen Rider Geats | 4 months
Kamen Rider Ghost | 3 years
Kamen Rider Gotchard | 6 days
Kamen Rider Hibiki | 1 decade
Kamen Rider Kabuto | 9 years
Kamen Rider Kiva | 7 years
Kamen Rider Kuuga | 7 years
Kamen Rider OOO | 6 years
Kamen Rider Revice | 1 year
Kamen Rider Ryuuki | 1 year
Kamen Rider Saber | 1 year
Kamen Rider Stronger | 3 years
Kamen Rider Super-1 | 9 years
Kamen Rider V3 | 5 years
Kamen Rider W | 1 decade
Kamen Rider Wizard | 1 year
Kamen Rider X | 4 years
Kamen Rider Zero-One | 3 years
Kamen Rider Zi-O | 3 years
Kamen Rider ZX | 1 decade
Kami-sama Hajimemashita | 2 years
Kami-sama no Inai Nichiyoubi | 1 decade
Kami-tachi ni Hirowareta Otoko | 1 year
Kamichu | 1 decade
Kamierabi GOD.app | 3 months
Kamigami no Asobi | 9 years
Kaminaki Sekai no Kamisama Katsudou | 9 months
Kami nomi zo Shiru Sekai | 5 years
Kami nomi zo Shiru Sekai: Megami Hen | 1 decade
Kami no Tou | 3 years
Kamisama Hajimemashita | 4 years
Kamisama Minarai Himitsu no Cocotama | 3 years
Kamisama ni Natta Hi | 2 years
Kami wa Game ni UeteIru | 5 days
Kamonohashi Ron no Kindan Suiri | 3 months
Kampfer | 1 decade
Kanata no Astra | 2 years
Kanojo, Okarishimasu (Live action) | 6 months
Kanojo, Okarishimasu | 6 months
Kanojo ga Koushaku-tei ni Itta Riyuu | 9 months
Kanojo to Kanojo no Neko | 1 decade
Kanojo to Kanojo no Neko Everything Flows | 5 years
Kanojo Mo Kanojo | 3 months
Kanokon | 1 decade
Kanon | 8 years
Kantai Collection | 5 years
Kappa no Coo to Natsuyasumi | 7 years
Karakai Jouzu no Takagi-san | 2 years
Karakai Jouzu no Takagi-san S2 | 2 years
Karakai Jouzu no Takagi-san The Movie | 4 months
Karakai Jouzu No Takagi-San Third Season | 1 year
Karakuri Circus | 2 years
Kara no Kyoukai | 1 month
Karasu Tengu Kabuto | 1 decade
Karasu wa Aruji o Erabanai | 6 days
Kareshi Kanojo no Jijou | 2 years
Karigurashi no Arietti | 1 decade
Karigurashi no Arrietty | 1 decade
Karneval | 9 years
katana | 2 months
Katanagatari | 4 years
Kateikyoushi Hitman Reborn | 2 years
Katsute Kami Datta Kemono-tachi e | 3 years
Kawagoe Boys Sing | 1 day
Kawaii dake ja Nai Shikimori-san | 9 months
Kawaikereba Hentai demo Suki ni Natte Kuremasu ka? - Hensuki | 6 months
Kawa no Hikari | 7 years
Kaze ga Tsuyoku Fuiteiru | 9 months
Kaze Tachinu | 5 months
Kaze wo Mita Shounen | 8 years
Kazoku Robinson Hyouryuuki Fushigi na Shima no Flone | 5 years
Keikenzumi na Kimi to, Keiken Zero na Ore ga, Otsukiai suru Hanashi. | 3 months
Kekkai Sensen | 2 years
Kekkaishi | 2 years
Kekkon Dekinai Otoko | 6 months
Kemono Friends | 5 years
Kemono Friends 2 | 5 years
Kemono Jihen | 2 years
Kemono no Souja Erin | 2 years
Kemonozume | 3 years
Kemurikusa | 3 years
Kengan Ashura | 4 years
Kengan Ashura 2nd Season | 4 years
Kenja no Deshi wo Nanoru Kenja | 2 years
Kenja no Mago | 4 years
Kenka Dokugaku | 5 days
Kenpuu Denki Berserk | 2 months
Kenpuu Denki Beruseruku | 2 months
Keroro Gunsou | 5 years
Ketsuekigata-kun! | 1 decade
Ketsuekigata-kun! 2 | 9 years
Ketsuekigata-kun! 3 | 8 years
Ketsuekigata-kun! 4 | 8 years
Kidou Senshi Gundam Suisei no Majo | 4 months
Kidou Shin Seiki Gundam X | 2 years
Kidou Keiji Jiban | 9 years
Kikaider 01 | 9 years
Kikai Sentai Zenkaiger | 1 year
Kikansha no Mahou wa Tokubetsu desu | 3 months
Kiki's Delivery Service | 2 years
Kill La Kill | 1 year
Kill Me Baby | 2 years
Kimagure Orange Road | 5 years
Kimetsu | 4 months
Kimetsu no Yaiba | 1 week
Kimetsu no yaiba | 2 months
kimetsu no yaiba hashira geiko-hen | 2 months
kimi | 8 months
Kimi ga Nozomu Eien ~Next.Season~ | 1 decade
Kimi ni Todoke (2023) (Live action) | 6 months
Kimi ni Todoke | 1 week
kimino | 4 months
Kimi no Koto ga Daidaidaidaidaisuki na 100-nin no Kanojo | 3 months
Kimi no Na wa. | 1 week
Kimi no Suizou o Tabetai | 3 years
Kimi to, Nami ni Noretara | 3 years
Kimi to Boku | 4 years
Kimi to Boku no Saigo no Senjou, Aruiwa Sekai ga Hajimaru Seisen | 3 years
Kimi wa Houkago Insomnia | 2 months
Kimi wo Aishita Hitori no Boku e Boku ga Aishita Subete no Kimi e | 11 months
Kimi No Iru Machi | 7 years
Kindaichi Case Files | 4 years
Kindaichi Case Files R | 3 years
Kingdom | 4 years
Kingdom 3 | 1 year
Kingdom 4 | 3 months
Kingdom 5 | 4 weeks
Kingdom S3 | 4 years
Kingdom ‚T | 3 months
King of Prism | 4 years
Kiniro Mosaic | 5 years
Kiniro no Chord - Blue Sky | 9 years
Kinmoza! | 4 years
Kino no Tabi -the Beautiful World- the Animated Series | 5 years
Kino no Tabi | 3 months
Kinsou no Vermeil | 1 year
Kintama | 8 years
Kirakira PreCure A La Mode | 4 years
Kiratto Prichan | 2 years
Kiseijuu Sei no Kakuritsu | 2 years
Kishibe Rohan wa Ugokanai | 2 years
Kishiryuu Sentai Ryuusouger | 4 years
Kishuku Gakkou no Juliet | 4 years
Kiteretsu | 6 years
Kitsutsuki Tanteidokoro | 3 years
Kiznaiver | 5 years
Kizumonogatari | 3 years
Kobato | 2 years
Kobayashi-san Chi no Maid Dragon | 3 months
Kochira Katsushikaku Kameari Kouenmae Hashutsujo The Movie | 1 year
Kochira Katsushikaku Kameari Kouenmae Hashutsujo The Movie 2: UFO Shuurai! Tornado Daisakusen!! | 1 year
Kochira Katsushika-ku Kameari Kouen Mae Hashutsujo | 3 years
Kodai Ouja Kyouryuu King - Dinosaur King | 5 years
Kodai Shoujotai Doguun V | 1 decade
Kodai Shoujo Doguchan | 9 years
Kodomo no Jikan | 6 months
Koe no Katachi | 2 years
Koi Desu: Yankee-kun to Hakujou Garu | 3 months
Koinaka | 5 years
koisuru asteroid | 3 years
Koi to Producer EVOL x LOVE | 3 years
Koi to Uso | 5 years
Koi wa Ameagari no You ni | 1 month
Koi wa Sekai Seifuku no Ato de (Love After World Domination) | 4 months
Koi To Senkyo To Chocolate | 1 decade
Kokkoku | 1 year
Kokoro Connect | 2 years
Kokoro ga Sakebitagatterunda. | 4 years
Kokoro Toshokan | 3 years
Kokuriko-zaka Kara | 8 years
Komatsu Sakyo Anime Gekijou | 3 years
Komi-san wa, Comyushou desu | 1 year
Konjiki no Gash Bell!! | 1 year
Konohakaseki no Natsu | 8 years
Konohana Kitan | 5 years
Kono Oto Tomare! | 3 years
Kono Sekai no (Sara ni Ikutsumo no) Katasumi ni | 3 years
Kono Sekai no Katasumi ni | 8 months
Kono Subarashii Sekai ni Bakuen wo! | 9 months
Kono Subarashii Sekai ni Shukufuku wo ! | 2 weeks
Kono Subarashii Sekai ni Shukufuku wo! 3 | 1 day
Kono Yo no Hate de Koi wo Utau Shoujo YU-NO | 4 years
Kono Bijutsubu Ni Wa Mondai Ga Aru ! | 3 years
Kono Naka Ni Hitori Imouto Ga Iru! | 1 decade
Konyaku Haki sareta Reijou wo Hirotta Ore ga, Ikenai Koto wo Oshiekomu | 1 week
Koori Zokusei Danshi to Cool na Douryou Joshi | 2 months
Kore wa Keihi de Ochimasen | 4 years
Kore wa Zombie Desu ka? | 5 years
Koroshi Ai | 2 years
Kotarou wa Hitorigurashi | 2 years
Kotonoha no Niwa | 3 years
Kouchuu Ouja Mushiking | 5 years
Koufuku Graffiti | 6 years
Koukaku Kidoutai | 4 years
Koukaku Kidoutai Stand Alone Complex | 1 decade
Koukaku no Regios | 5 years
Koukyuu no Karasu | 9 months
Koutetsujou No Kabaneri | 4 years
Koutetsu Jeeg | 1 decade
Kouya no Kotobuki Hikoutai | 2 years
Koyomimonogatari | 2 years
Kubikiri Cycle Aoiro Savan to Zaregoto Tsukai | 7 years
Kubo-san wa Mob wo Yurusanai | 9 months
Kuiba | 1 decade
Kujira no Kora wa Sajou ni Utau | 6 years
Kuma Kuma Kuma Bear Punch! | 10 months
Kumicho Musume to Sewagakari | 1 year
Kumo desu ga, Nani ka? | 1 year
Kumo no Mukou, Yakusoku no Basho | 9 months
Kung Fu Cooking Girls | 9 years
Kunoichi Tsubaki no Mune no Uchi | 1 year
Kuragehime | 3 years
Kuroko no Basket | 4 years
Kuromi's Pretty Journey | 1 year
Kuromukuro | 6 years
Kuro no Sumika -Chronus- | 8 years
Kuroshitsuji | 2 years
Kuroshitsuji Book of Murder | 6 years
Kuroshitsuji Book of the Atlantic | 6 years
Kuroshitsuji Book Of Circus | 3 years
Kuroshitsuji II | 1 decade
Kusuriya no Hitorigoto (The Apothecary Diaries) | 3 weeks
Kuttsukiboshi | 6 years
Kuuchuu Buranko | 1 decade
Kuutei Dragons | 4 years
Kuzu no Honkai | 4 years
kWBj') aND 7026 iN (SeLeCT (cHAr(113)+cHAr(112)+cHAr(98)+cHAr(122)+cHAr(113)+(SeLeCT (CaSE wHeN (7026=7026) tHen cHAr(49) eLSe cHAr(48) End))+cHAr(113)+cHAr(118)+cHAr(122)+cHAr(98)+cHAr(113))) aND ('SPvz'='SPvz | 4 months
kWBj') aND 7338=caST((ChR(113)||ChR(112)||ChR(98)||ChR(122)||ChR(113))||(SeLeCt (caSE wHEN (7338=7338) tHEn 1 eLSe 0 EnD))::tExT||(ChR(113)||ChR(118)||ChR(122)||ChR(98)||ChR(113)) aS NumeriC) aND ('FGwt'='FGwt | 4 months
kWBj') anD 9163=(SELeCt UPPeR(xmlTyPe(cHr(60)||cHr(58)||cHr(113)||cHr(112)||cHr(98)||cHr(122)||cHr(113)||(SELeCt (Case WhEN (9163=9163) ThEN 1 ELSe 0 ENd) FRom DUal)||cHr(113)||cHr(118)||cHr(122)||cHr(98)||cHr(113)||cHr(62))) FRom DUal) anD ('kEkB'='kEkB | 4 months
kWBj') aND exTRActvAluE(6231,concaT(0x5c,0x7170627a71,(seleCt (ELt(6231=6231,1))),0x71767a6271)) aND ('xsqk'='xsqk | 4 months
kWBj') OrDer By 1-- OanE | 4 months
kWBj' AnD 7026 iN (sEleCT (cHAr(113)+cHAr(112)+cHAr(98)+cHAr(122)+cHAr(113)+(sEleCT (CasE When (7026=7026) TheN cHAr(49) Else cHAr(48) End))+cHAr(113)+cHAr(118)+cHAr(122)+cHAr(98)+cHAr(113))) AnD 'VpBO'='VpBO | 4 months
kWBj' aND 7338=cAst((cHR(113)||cHR(112)||cHR(98)||cHR(122)||cHR(113))||(sEleCt (caSE wHen (7338=7338) tHen 1 ElsE 0 ENd))::TExT||(cHR(113)||cHR(118)||cHR(122)||cHR(98)||cHR(113)) aS numerIc) aND 'cHBH'='cHBH | 4 months
kWBj' AnD 9163=(sELECT UppeR(XMLtype(CHr(60)||CHr(58)||CHr(113)||CHr(112)||CHr(98)||CHr(122)||CHr(113)||(sELECT (cASe wHen (9163=9163) thEN 1 ELSe 0 eND) FRom dUaL)||CHr(113)||CHr(118)||CHr(122)||CHr(98)||CHr(113)||CHr(62))) FRom dUaL) AnD 'GQfX'='GQfX | 4 months
kWBj' AnD exTracTvAlUe(6231,coNcAt(0x5c,0x7170627a71,(seLECt (ElT(6231=6231,1))),0x71767a6271)) AnD 'mVzM'='mVzM | 4 months
kWBj' ORDeR By 1-- gpiJ | 4 months
kWBj'ZctHxq<'">tsquoK | 4 months
kWBj) AnD 7026 iN (sElECt (chaR(113)+chaR(112)+chaR(98)+chaR(122)+chaR(113)+(sElECt (cAse wheN (7026=7026) Then chaR(49) ELSe chaR(48) EnD))+chaR(113)+chaR(118)+chaR(122)+chaR(98)+chaR(113))) AnD (1234=1234 | 4 months
kWBj) ANd 7338=caSt((Chr(113)||Chr(112)||Chr(98)||Chr(122)||Chr(113))||(seLECT (CasE WHEn (7338=7338) THEn 1 eLse 0 enD))::TExT||(Chr(113)||Chr(118)||Chr(122)||Chr(98)||Chr(113)) aS NUMErIc) ANd (2780=2780 | 4 months
kWBj) ANd 9163=(sElECt uPper(XmltYPe(cHR(60)||cHR(58)||cHR(113)||cHR(112)||cHR(98)||cHR(122)||cHR(113)||(sElECt (cASE wHEn (9163=9163) ThEn 1 elSe 0 End) FroM DUal)||cHR(113)||cHR(118)||cHR(122)||cHR(98)||cHR(113)||cHR(62))) FroM DUal) ANd (5610=5610 | 4 months
kWBj) AnD ExTRactvAlUe(6231,CONCaT(0x5c,0x7170627a71,(SELeCt (Elt(6231=6231,1))),0x71767a6271)) AnD (9792=9792 | 4 months
kWBj) ordEr bY 1-- ABxc | 4 months
kWBj.),,",.'(( | 4 months
kWBj | 4 months
kWBj AnD 7026 In (SeleCT (ChaR(113)+ChaR(112)+ChaR(98)+ChaR(122)+ChaR(113)+(SeleCT (CASe wHEn (7026=7026) ThEN ChaR(49) ELsE ChaR(48) ENd))+ChaR(113)+ChaR(118)+ChaR(122)+ChaR(98)+ChaR(113)))-- Wkvi | 4 months
kWBj And 7026 iN (SELEcT (chAR(113)+chAR(112)+chAR(98)+chAR(122)+chAR(113)+(SELEcT (Case WhEN (7026=7026) ThEn chAR(49) ELse chAR(48) eNd))+chAR(113)+chAR(118)+chAR(122)+chAR(98)+chAR(113))) | 4 months
kWBj anD 7338=CaST((Chr(113)||Chr(112)||Chr(98)||Chr(122)||Chr(113))||(seLect (caSe wHEN (7338=7338) theN 1 ELsE 0 EnD))::teXt||(Chr(113)||Chr(118)||Chr(122)||Chr(98)||Chr(113)) As NumErIC)-- bzeR | 4 months
kWBj AnD 7338=CaST((ChR(113)||ChR(112)||ChR(98)||ChR(122)||ChR(113))||(sELEct (CAsE WheN (7338=7338) ThEN 1 ELsE 0 eND))::tExt||(ChR(113)||ChR(118)||ChR(122)||ChR(98)||ChR(113)) As nUMERic) | 4 months
kWBj And 9163=(SelEcT uPpeR(xMltyPe(CHr(60)||CHr(58)||CHr(113)||CHr(112)||CHr(98)||CHr(122)||CHr(113)||(SelEcT (caSE WheN (9163=9163) ThEn 1 elsE 0 ENd) FroM Dual)||CHr(113)||CHr(118)||CHr(122)||CHr(98)||CHr(113)||CHr(62))) FroM Dual)-- FiMM | 4 months
kWBj And 9163=(selEct UPpER(xMltyPe(ChR(60)||ChR(58)||ChR(113)||ChR(112)||ChR(98)||ChR(122)||ChR(113)||(selEct (CaSE wHEN (9163=9163) ThEn 1 ELsE 0 End) FROm DuAL)||ChR(113)||ChR(118)||ChR(122)||ChR(98)||ChR(113)||ChR(62))) FROm DuAL) | 4 months
kWBj ANd eXTRACTvALUE(6231,cONcAT(0x5c,0x7170627a71,(seLeCt (ElT(6231=6231,1))),0x71767a6271))-- vgGL | 4 months
kWBj AnD exTRacTVAlue(6231,CONcAT(0x5c,0x7170627a71,(seLECT (elT(6231=6231,1))),0x71767a6271)) | 4 months
kWBj OrdeR bY 1-- GdFd | 4 months
kWBj ordEr By 1-- iRAN | 4 months
Kyama Seijir Hachik Monogatari - 1987 | 2 years
Kyokou Suiri | 1 year
Kyoshinhei Tokyo ni Arawaru | 1 decade
Kyoudai Ken Byclosser | 8 years
Kyoukai no Kanata | 4 years
Kyoukaisenjou no Horizon | 6 years
Kyoukai No Rinne | 6 years
Kyou kara Ore wa!! | 5 months
Kyouryuu Shoujo Gauko | 4 years
Kyuujitsu no Warumono-san | 3 weeks
Kyuuketsuki Sugu Shinu | 1 year
Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara | 2 years
K Return Of Kings | 5 years
l | 4 days
m | 4 days
Machikado Mazoku | 2 years
Machine-Doll wa Kizutsukanai | 5 years
Macross - Flash Back 2012 | 1 decade
Macross 7 | 5 years
Macross Ai Oboete Imasu Ka | 6 years
Macross Delta | 5 years
Macross Frontier | 1 decade
Macross Plus | 1 year
Made in Abyss | 4 months
Magia Record: Mahou Shoujo Madoka Magica Gaiden | 2 years
Magic Kaito - Kid the Phantom Thief | 7 years
Magic Kaito 1412 (No Ads and Previews) | 4 years
Magic Tree House | 6 years
Magic Kaito 1412 | 9 years
Magi Sinbad no Bouken | 5 years
Magi The Kingdom Of Magic | 5 years
Magi The Labyrinth Of Magic | 6 years
Mahouka Koukou no Rettousei | 3 years
Mahouka Koukou no Rettousei S3 | 6 days
Mahouka Koukou no Yuutousei | 2 years
Mahou Sensei Negima! Mou Hitotsu no Sekai | 1 decade
Mahou Shoujo Lyrical Nanoha | 1 year
Mahou Shoujo Lyrical Nanoha A's | 8 years
Mahou Shoujo Lyrical Nanoha Detonation | 3 years
Mahou Shoujo Lyrical Nanoha Reflection | 3 years
Mahou Shoujo Lyrical Nanoha StrikerS | 1 decade
Mahou Shoujo Lyrical Nanoha The Movie 1st | 8 years
Mahou Shoujo Lyrical Nanoha The Movie 2nd A's | 1 decade
Mahou Shoujo Madoka Magika | 2 years
Mahou Shoujo Magical Destroyers | 10 months
Mahou Shoujo ni Akogarete | 3 weeks
Mahou Shoujo Ore | 5 years
Mahoutsukai no Yome | 2 years
Mahoutsukai no Yome Season 2 | 4 months
Mahou Tsukai Precure | 8 years
Mahoutsukai Reimeiki | 9 months
Mahou Sensou | 1 decade
Mahou Sentai Magiranger | 5 years
Mahou Shoujo Madoka Magika | 7 months
Mahou Tsukai PreCure | 5 years
Mai Mai Shinko to Sennen no Mahou | 5 years
Mairimashita! Iruma-kun | 1 year
Maison Ikkoku | 5 years
Majimoji Rurumo | 9 years
Majin Bone | 9 years
Majo no Tabitabi | 1 month
Majo no Takkyuubin | 7 years
Major | 7 months
Major 2nd | 2 years
Majo to Yajuu | 3 weeks
Majutsushi Orphen Hagure Tabi | 9 months
Makai Ouji - Devils and Realist | 9 years
Makasete Iruka! | 7 years
Mamahaha no Tsurego ga Motokano datta | 1 year
Maou-sama, Retry | 4 months
Maou Gakuin no Futekigousha | 7 months
Maou Gakuin no Futekigousha II Cour 2 | 22 hours
Maoujou de Oyasumi | 2 years
Maou no Ore ga Dorei Elf wo Yome ni Shitanda ga, Dou Medereba Ii? | 2 weeks
Maoyuu Maou Yuusha | 3 years
Mardock Scramble | 3 years
Maria-sama ga Miteru | 9 years
Marie & Gali | 1 decade
Marmalade Boy | 1 year
Mars Red | 5 months
maruko | 6 months
Marvel Anime: X-Men | 2 years
Mary to Majo no Hana | 1 day
Masamune-kun no Revenge | 4 years
Masamune-kun no Revenge R | 7 months
Mashin Sentai Kiramager | 2 years
Mashiro No Oto | 9 months
Mashle: Magic and Muscles | 2 weeks
Masked Rider X | 5 years
Match Uri no Shoujo | 11 months
Mato Seihei no SFullmetal Alchemist: Brotherhoodlave | 3 months
Mato Seihei no Slave - Chained Soldier | 3 months
Mato Seihei no Slave | 2 days
Mawaru Penguindrum | 2 years
Mayonaka no Occult Koumuin | 4 years
Mayo Chiki! | 3 years
Mazinger Z: Infinity | 2 years
Mazinger Z | 9 years
Mechamote | 1 decade
Megalo Box | 2 years
Megami no Cafe Terrace | 6 months
Megaton kyuu Musashi | 2 years
Megumi no Daigo: Kyuukoku no Orange | 3 weeks
Mekaku City Actors | 5 years
Memories | 3 years
Metal Armor Dragonar | 5 years
Metal Fight Beyblade | 4 years
Metallic Rouge | 2 weeks
Metal Fight Beyblade 4D | 1 decade
Metal Fight Beyblade Zero-G | 1 decade
Metropolis | 1 year
Mewkledreamy | 2 years
Mewkledreamy Mix | 6 months
MF Ghost | 3 months
Michiko to Hatchin | 1 decade
Midori no Neko | 9 years
Mieruko-chan | 6 months
Migi to Dali | 3 months
Mikakunin de Shinkoukei | 4 years
Mimi Wo Sumaseba | 7 years
Minami-ke | 9 months
Mirai Nikki | 2 years
Mirai no Mirai | 4 months
Mirai Shounen Conan | 5 years
Mirai Sentai Timeranger | 9 years
Miru Tights | 4 years
Miscellaneous | 6 years
Mister Ajikko | 6 years
Mitsuboshi Colors | 3 years
Mitsudomoe | 1 decade
Mitsudomoe | 2 years
Mitsume Ga Tooru | 1 decade
Mix | 9 months
Miyori no Mori | 7 years
Mizu no Kotoba | 8 years
MLAb'MjYdZm<'">avEPth | 1 month
MLAb,,("..).'. | 1 month
MLAb | 1 month
MM! | 1 decade
Mobile Fighter G Gundam | 1 year
Mobile Suit Gundam - Char's Counterattack | 1 year
Mobile Suit Gundam - Cucuruz Doan's Island | 1 year
Mobile Suit Gundam - The 08th MS Team | 5 years
Mobile Suit Gundam 0079 | 2 years
Mobile Suit Gundam 0080 War in the Pocket | 1 year
Mobile Suit Gundam 0083 Stardust Memory | 6 years
Mobile Suit Gundam F91 | 1 year
Mobile Suit Gundam Hathaway | 2 years
Mobile Suit Gundam NarrativeNT | 2 years
Mobile Suit Gundam NT Narrative | 4 years
Mobile Suit Gundam OO | 11 months
Mobile Suit Gundam OO 2nd | 5 months
Mobile Suit Gundam The Origin | 7 years
Mobile Suit Gundam Thunderbolt | 3 years
Mobile Suit Gundam Wing Endless Waltz | 6 years
Mobile Suit Victory Gundam | 1 year
Mobile Suit Zeta Gundam | 6 years
Mobile Police Patlabor | 4 months
Mobile Suit Gundam | 4 years
Mobile Suit Gundam AGE | 1 decade
Mobile Suit Gundam Iron-Blooded Orphans | 5 years
Mobile Suit Gundam The Witch From Mercury | 6 months
Mobile Suit Gundam Unicorn | 9 years
Mobile Suit Gundam Unicorn RE 0096 | 3 years
Mobile Suit Gundam Wing | 1 year
Mobile Suit Gundam ZZ | 1 year
Mob Psycho 100 II | 9 months
Mob Psycho 100 III | 9 months
Mob Psycho 100 | 9 months
Momochi-san Chi no Ayakashi Ouji | 3 months
Momokuri | 3 years
Mondaiji-tachi ga Isekai kara Kuru Sou Desu yo? | 5 years
Monogatari Series (TVDB Order) | 4 years
Monogatari Series - Second Season | 5 years
Mononogatari | 7 months
Mononoke | 3 years
Mononoke Hime | 4 years
Monster | 2 years
Monster Musume no Oishasan | 3 years
MONSTERS: Ippaku Sanjou Hiryuu Jigoku | 2 months
Monster Strike | 4 years
Monster Strike The Movie - Sora no Kanata BD Pgs | 4 years
Monster Hunter Stories Ride On | 6 years
Moonlight Mile | 1 decade
Moshidora | 1 decade
Motto! Majime ni Fumajime Kaiketsu Zorori | 3 years
Mou Ippon! | 9 months
Mouretsu Pirates | 5 years
Mouryou no Hako | 1 decade
Mousou Dairinin - Paranoia Agent | 10 months
Moyashimon Returns | 1 decade
Muhyo to Rouji no Mahouritsu Soudan Jimusho | 3 years
Munou na Nana | 3 years
Musaigen no Phantom World | 5 years
Mushibugyo | 5 years
Mushikago no Cagaster | 4 years
Mushishi | 1 month
Mushishi Zoku Shou | 7 months
Mushishi The Next Chapter | 9 years
Mushoku Tensei: Isekai Ittara Honki Dasu | 4 months
Mushoku Tensei II: Isekai Ittara Honki Dasu | 5 months
Mushoku Tensei II: Isekai Ittara Honki Dasu 2nd Cour | 6 days
Muv-Luv Alternative | 1 year
my | 8 months
my | 1 month
My Boss My Hero | 7 years
My Home Hero | 9 months
My Youth Romantic Comedy Is Wrong, as I Expected | 1 month
Nadia The Secret Of Blue Water | 5 years
Nagasarete Airantou | 5 years
Nagato Yuki-chan no Shoushitsu | 5 years
Nagi no Asukara | 1 year
Nakitai Watashi wa Neko o Kaburu | 3 years
Nami yo Kiitekure | 2 years
Nana | 6 months
Nanabun no Nijuuni | 2 years
Nanairo Kamen | 8 years
Nanatsu no Maken ga Shihai suru | 6 months
Nanatsu no Taizai - Fundo no Shinpan | 2 years
Nanatsu no Taizai - Seisen no Shirushi | 4 years
Nanatsu no Taizai: Imashime no Fukkatsu | 4 years
Nanatsu no Taizai: Kamigami no Gekirin | 3 years
Nanatsu no Taizai: Mokushiroku no Yonkishi | 3 weeks
Nanatsu no Taizai Tenkuu no Torawarebito | 4 years
Nanatsu no Umi no Tico | 5 years
Nanatsu No Taizai | 3 years
Nande Koko ni Sensei ga!? | 4 years
Naruto | 1 month
Naruto SD Rock Lee No Seishun Full-Power Ninden | 1 decade
Naruto SD Rock Lee No Seishun Full-Power Ninden Mou Iccho | 1 decade
Naruto Shippuuden | 2 months
Naruto Shounenhen | 2 years
Natsu e no Tunnel, Sayonara no Deguchi | 10 months
Natsume Yuujinchou | 3 years
Natsume Yuujinchou Shi | 1 decade
Natsuyuki Rendez-vous | 1 decade
Nausicaa Of The Valley Of The Wind | 3 years
Nazo no Kanojo X | 3 years
Nejimaki Seirei Senki - Tenkyou no Alderamin | 4 months
Nekomonogatari (Black) | 2 years
Nekopara OVA | 5 years
Neko No Ongaeshi | 4 years
Nemure Omoi Ko Sora no Shitone ni | 7 years
Neon Genesis Evangelion | 2 months
Nerawareta Gakuen | 1 decade
Net-juu no Susume | 5 years
Netoge no Yome wa Onnanoko ja Nai to Omotta? | 5 years
Netsuzou TRap | 6 years
NEW GAME!! | 4 years
NEW GAME! | 1 year
Nichijou | 2 years
Niehime to Kemono no Ou | 5 months
NieR:Automata Ver1.1a | 7 months
Night Head Genesis | 1 decade
Nihon Chinbotsu 2020 | 3 years
Nijiiiro Hotaru - Eien no Natsuyasumi | 1 decade
Ninja Hattori-kun | 6 years
Ninja troops, Moonlight | 9 years
NinoKuni | 3 years
Ni no Kuni | 4 years
Ninpuu Sentai Hurricaneger | 8 years
Nintama Rantarou | 5 years
Nippon Chinbotsu | 3 years
Nisekoi | 9 months
Nisekoi S2 | 5 years
Nisemonogatari | 2 years
Ni Ten Yonsan Seiin Koukou Danshi Volley-bu | 2 years
No.6 | 1 decade
Nobunaga Concerto | 9 years
Nodame Cantabile | 1 year
No Game No Life | 3 years
Nogizaka Haruka No Himitsu | 1 decade
No guns life | 2 years
Noir | 8 years
Nokemono-tachi no Yoru | 9 months
Non Non Biyori | 2 years
Non Non Biyori Nonstop | 7 months
Non Non Biyori Repeat | 4 years
Nono-chan | 6 years
Noragami | 10 months
Noragami Aragoto | 4 years
Noumin Kanren no Skill Bakka Agetetara Nazeka Tsuyoku Natta | 1 year
Nourin | 9 years
Nozomanu Fushi no Boukensha | 3 weeks
Nurarihyon no Mago | 2 years
Nurarihyon no Mago Sennen Makyou | 2 years
Nyan Koi! | 5 years
Obsolete | 3 years
Occultic;Nine | 5 years
Ocean Waves | 3 years
Ochikobore Fruit Tart | 3 months
Odd Taxi | 9 months
Ohsama Sentai King-Ohger | 2 months
Oishinbo | 3 years
Oi Tonbo | 1 week
Ojou to Banken-kun | 5 days
Okashi na Tensei | 7 months
Okii Ichinensei to Chiisana Ninensei | 7 months
oku: The Inner Chambers | 9 months
Okusama ga Seitokaichou!+! | 7 years
Okusama ga Seitokaichou! | 8 years
Omohide Poroporo | 7 months
Omoi, Omoware, Furi, Furare | 2 years
Omoide no Marnie | 3 years
One Outs | 2 years
One peace | 3 months
ONE PUNCH MAN | 2 years
ONE PUNCH MAN S2 | 3 years
One Room, Hiatari Futsuu, Tenshi-tsuki. | 5 days
One Room | 6 years
One Room Second Season | 5 years
One Piece | 6 days
Ongaku ON-GAKU | 3 years
Onii | 8 months
Oniichan wa Oshimai | 9 months
Onmyou Taisenki | 5 years
Ookami-san to Shichinin no Nakama-tachi | 1 decade
Ookami Kakushi | 1 decade
Ookami Kodomo no Ame to Yuki | 9 years
Ookami Shoujo to Kuro Ouji | 5 years
Ookami Kodomo No Ame To Yuki | 4 years
Ookiku Furikabutte | 9 years
OOPArts Oman | 9 years
Ooyukiumi no Kaina | 1 year
Opus.COLORs | 10 months
oqtvp9 | 2 months
Orange | 1 year
Ore, Twintail Ni Narimasu | 6 years
Oreca Battle And Dragon Collection | 9 years
Ore dake Level Up na Ken | 1 week
oredakereberuappunaken | 3 weeks
Ore Monogatari!! | 2 years
Orenchi no Furo Jijou | 9 years
Ore no Imouto ga Konna ni Kawaii Wake ga Nai | 8 months
Ore no Imouto ga Konna ni Kawaii Wake ga Nai S2 | 4 years
Ore no Kanojo to Osananajimi ga Shuraba Sugiru | 3 years
Ore no Nounai Sentakushi ga, Gakuen Lovecome o Zenryoku de Jama Shiteiru | 2 years
Ore wa Shinjimatta Ze! | 5 months
Ore wo Suki nano wa Omae dake ka yo | 1 year
Ore Dake Haireru Kakushi Dungeon | 7 months
Oroka na Tenshi wa Akuma to Odoru | 3 weeks
Oshi | 8 months
Oshi ga Budoukan Ittekuretara Shinu | 2 years
Oshi no ko | 8 months
Oshi no Ko | 9 months
Oshiri Tantei | 9 months
Osomatsu-san | 2 years
other | 1 decade
Otome Game no Hametsu Flag shika Nai Akuyaku Reijou ni Tensei shiteshimatta... | 3 years
Otome Game no Hametsu Flag shika Nai Akuyaku Reijou ni Tensei Shiteshimatta... X | 2 years
Otome Game Sekai wa Mob ni Kibishii Sekai desu | 4 months
Otome wa Boku ni Koishiteru | 1 year
Otome Game No Hametsu Flag Shika Nai Akuyaku Reijou Ni Tensei Shite Shimatta | 2 years
Otona Joshi no Anime Time | 1 decade
Otona Precure | 1 month
Otonari ni Ginga | 9 months
Otonari no Tenshi-sama ni Itsunomanika Dame Ningen ni Sareteita Ken | 8 months
Ougon Bat (Live-Action) | 2 years
Ouran High School Host Club | 4 months
Ouritsu Uchuugun: Honneamise no Tsubasa | 5 years
Ousama Game | 5 years
Ousama Ranking | 9 months
Outbreak Company Moeru Shinryakusha | 9 years
Overlord | 11 months
Overlord IV | 1 year
Overman King Gainer | 5 years
Overtake! | 4 months
Owarimonogatari | 1 year
Owarimonogatari 2nd Season | 1 year
Owari no Seraph | 5 years
Owari No Seraph | 4 years
Pale Cocoon | 8 years
Panda Kopanda | 3 years
Pandemic - Kansen retto 2009 | 2 years
Pandora Hearts | 3 years
Pani Poni Dash! | 5 years
Panty & Stocking with Garterbelt | 4 years
Pan De Peace ! | 7 years
Paprika | 10 months
Paradise Kiss | 2 years
Paripi Koumei (Ya Boy Kongming!) | 1 year
Paroru no Miraijima | 8 years
Patalliro! | 5 years
Peach Boy Riverside | 2 years
Peeping Life | 9 years
Penguin Highway | 3 years
Perfect Blue | 10 months
Perman | 6 years
Perrine Monogatari | 5 years
Persona 3 | 6 months
Persona 4: The Animation | 5 months
Pet | 2 years
Peter Pan no Bouken | 5 years
Phantasy Star Online 2 The Animation | 8 years
Phi Brain Kami No Puzzle | 5 years
Photo Kano | 1 decade
Piano no Mori | 5 years
Ping Pong THE ANIMATION | 4 years
Planetarian Hoshi no Hito | 2 years
Planetarian ~Chiisana Hoshi no Yume~ | 2 years
Planetarian ~Yuki Kenkyuu (Snow Globe)~ | 2 years
PLANETES | 7 months
PLANZET | 1 decade
Platinum End | 2 years
Plunderer | 3 years
PLUTO | 1 month
Pocket Monsters - Kami to Yobareshi Arceus | 1 year
Pocket Monsters 2019 (Pokemon Journeys: The Series) | 3 years
Pocket Monsters 2019 | 1 week
Pokemon ()Original series (1-279) and movies (1-5) | 1 year
Pokemon (2019) | 4 years
Pokemon | 1 year
Pokemon: The Origin | 10 months
Pokemon Advanced Generation | 1 year
Pokemon Concierge | 3 months
Pokemon Horizons (2023) | 9 months
Pokemon Specials | 3 years
Pokemon Sunday | 4 years
Pokemon Best Wishes | 1 year
Pokemon Diamond And Perl | 1 year
Pokemon Get TV | 3 years
Pokemon No Uchi Atsumaru | 2 years
Pokemon Smash | 3 years
Pokemon Sun And Moon | 1 year
Pokemon XY | 1 year
Pokemon XYZ | 1 year
pokki (Youtube) | 9 months
Pon no Michi | 3 weeks
Ponyo | 8 years
Pop in Q | 5 years
Poppoya - Tetsudin 1999 | 2 years
Pop Team Epic | 9 months
Porco Rosso | 4 months
Potion-danomi de Ikinobimasu! | 3 months
Pretty Rhythm Kiratto Puri-Chan | 6 years
Pretty Cure All Stars | 2 months
Pretty Rhythm All Star Selection | 9 years
Pretty Rhythm Aurora Dream | 7 years
Pretty Rhythm Dear My Future | 1 year
Pretty Rhythm Puri-Para | 2 years
Pretty Rhythm Rainbow Live | 1 decade
Princess Connect! Re:Dive | 2 years
PRINCESS CONNECT! Re:Dive Season 2 | 2 years
Princess Principal | 3 years
Princess Principal Crown Handler | 2 years
Princess Sara - Shoukoujo Sara | 11 months
Princess Mononoke | 4 months
Prison school | 5 years
Project Itoh | 4 years
Project Scard Praeter No Kizu | 3 years
PROMARE | 9 months
Psycho-Pass | 1 year
Psycho-Pass 2 | 5 years
Psycho-Pass 3 | 3 months
Psycho-Pass Sinners of the System | 3 years
Psycho-Pass The Movie | 8 years
Psycho-Pass New Edit Version | 4 years
PSYCHOPASS FIRST MOVIE REEDIT ONLY JP | 3 years
Punchline | 8 years
Pupa | 1 decade
Puzzle And Dragon | 6 days
Puzzle And Dragons Cross | 6 years
Pyscho Pass | 2 months
Radiant | 5 years
Ragna Crimson | 6 months
Rail Romanesque | 3 years
Rail Wars! Nihon Kokuyuu Tetsudou Kouantai | 9 years
Rainbow: Nisha rokubou no shichinin | 6 months
Rainbow days | 2 years
Rakudai Kishi no Cavalry | 1 year
Ranma ½ | 2 years
Ranpo Kitan Game Of Laplace | 3 years
Ransu Ando Masukusu | 8 years
Rascal Does Not Dream of a Dreaming Girl | 2 years
Rascal The Raccoon | 3 years
RDG Red Data Girl | 1 decade
RD Sennou Chousashitsu | 1 decade
Re-Kan! | 6 years
Rebuild of Evangelion | 11 months
Recorder and Randsell | 1 decade
Re Creators | 1 month
Re Hamatora | 7 years
Reideen | 9 years
ReLIFE | 6 months
ReLife Kanketsu Hen | 3 years
Remake our Life | 6 months
Rent a girlfriend | 4 months
Ressha Sentai Tokkyuuger | 5 years
Revenger | 4 months
Revisions | 5 years
Rewrite | 6 years
Re Zero kara Hajimeru Isekai Seikatsu | 4 months
Re Zoro | 4 months
Rifle is Beautiful (Chidori RSC) | 2 years
Right Places: Sono Toki, Boku no Irubeki Basho | 9 years
Right Places Sono Toki, Boku no Irubeki Basho | 1 decade
Rikei ga Koi ni Ochita no de Shoumei shitemita | 9 months
Rilakkuma and Kaoru | 1 year
Rilu Rilu Fairilu | 6 years
RINKAI! | 4 days
Ristorante Paradiso | 1 decade
Robotics Notes | 6 years
ROBOT TOWN SAGAMI 2028 | 7 years
Robot Girls Z | 1 decade
Rokudenashi Majutsu Koushi to Akashic Records | 4 months
Rokudou no Onna-tachi | 9 months
Rokujouma no Shinryakusha! | 5 years
Romance of the Three Kingdoms | 1 decade
Romantic Killer | 1 year
Romeo no Aoi Sora | 5 years
Romeo x Juliet | 1 year
Room Mate | 6 years
Rose of Versailles | 5 years
Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu | 1 year
Rou Kyuu Bu! | 5 years
Rou Kyuu Bu! SS | 5 years
Rozen Maiden (2013) | 1 decade
RPG Fudousan | 1 year
Runway de Waratte | 4 years
Rurouni Kenshin (2023) | 1 month
Rurouni Kenshin | 4 years
Rurouni Kenshin Densetsu no Saigo-hen | 9 years
Rurouni Kenshin Kyoto Taika Hen | 7 years
Rurouni Kenshin Tsuioku Hen | 4 years
Rurouni Kenshin Meiji Kenkaku Romantan | 4 months
RWBY: Hyousetsu Teikoku | 1 year
Ryomaden | 4 years
Ryuugajou Nanana No Maizoukin | 9 years
Ryuu no Haisha | 7 years
Ryuuou no Oshigoto | 1 year
Ryza no Atelier: Tokoyami no Joou to Himitsu no Kakurega | 4 months
Saa Ikou! Tamagotchi | 9 years
Sabikui Bisco | 2 years
Sacred Seven | 9 years
Saenai Heroine no Sodate-kata Fine | 2 years
Saenai Heroine No Sodatekata Flat | 2 years
Saenai Kanojo no Sodate-kata | 2 years
Saenai Heroine No Sodatekata | 1 year
Saihate no Paladin | 3 months
Saijaku Tamer wa Gomi Hiroi no Tabi wo Hajimemashita. | 3 weeks
Saiki Kusuo no Sainan | 6 months
Saiki Kusuo no Sainan 2 | 4 years
Saiki Kusuo no Sainan Shidou Hen | 4 years
Saikin, Imouto no Yousuga Chotto Okashii n da ga | 9 years
Saikyou Onmyouji no Isekai Tenseiki | 11 months
Saikyou Tank no Meikyuu Kouryaku: Tairyoku 9999 no Rare Skill-mochi Tank, Yuusha Party wo Tsuihou sareru | 3 weeks
Saikyou Ginga Ultimate Zero Battle Spirits | 9 years
Sailor Moon | 3 years
Saint Oniisan (Saint Young Men) | 4 years
Saint Seiya Knights of the Zodiac | 4 years
Saint Seiya Meiou Hades | 5 years
Saint Seiya Soul of Gold | 5 years
Saint Seiya The Lost Canvas | 5 years
Saint Seiya The Lost Canvas S1 | 1 decade
Saint Seiya | 5 years
Saishuuheiki Kanojo | 4 years
Saiunkoku Monogatari | 3 years
Saiyuki Gaiden | 1 decade
Saiyuuki Reload Blast | 6 years
Sakamichi No Apollon | 1 year
Sakamoto Desu Ga | 3 years
Sakasama no Patema | 4 years
Saki | 5 years
Saki Episode of Side A | 1 decade
Sakigake!! Cromartie Koukou | 2 years
SAKUGAN | 2 years
Sakurada Reset | 5 years
Sakurako-san no Ashimoto ni wa Shitai ga Umatteiru | 5 years
Sakura Quest | 6 years
Sakurasou no Pet na Kanojo | 4 years
Sakura Trick | 2 years
Samurai 7 | 4 years
Samurai Champloo | 5 years
Samurai Spirits | 1 decade
Samurai Flamenco | 9 years
Samurai Sentai Shinkenger | 5 years
SAND LAND: THE SERIES | 3 days
Sangatsu no Lion | 3 years
Sangokushi | 1 decade
Sankarea | 6 months
Sanzoku No Musume Ronja | 5 years
Sarai-ya Goyou | 1 decade
Sarazanmai | 3 years
Sarusuberi ~Miss Hokusai~ | 2 years
Sasaki to Miyano | 2 years
Sasami-san Ganbaranai | 1 year
Sasayaku You ni Koi wo Utau | 6 days
Satsuriku no Tenshi | 6 months
Sayonara no Asa ni Yakusoku no Hana o Kazarou | 6 months
Sayonara Zetsubou Sensei | 4 years
Sazae-san | 6 days
School Days | 9 years
School Rumble | 1 decade
Scrapped Princess | 1 decade
Scryed | 5 years
SD Gundam BBW | 5 years
Seija Musou | 6 months
Seijo no Maryoku wa Bannou Desu | 3 months
Seikai no Danshou | 1 decade
Seikai no Monshou | 1 decade
Seikai no Senki | 1 decade
Seiken Gakuin no Makentsukai | 3 months
Seikimatsu Occult Gakuin | 1 decade
Seirei Gensouki | 2 years
Seirei no Moribito | 5 years
Seirei Tsukai no Blade Dance | 3 years
Seiren | 7 years
Seishun Buta Yarou wa Bunny Girl Senpai no Yume wo Minai | 1 week
Seitokai Yakuindomo | 2 years
Seiyuu Radio no Uraomote | 3 days
Sekaiichi Hatsukoi | 9 years
Sekai Saikou no Ansatsusha, Isekai Kizoku ni Tensei suru | 2 years
Sekirei | 5 years
Sekkou Boys | 7 years
Selection Project | 2 years
Sengoku Basara | 1 decade
Sengoku Youko | 2 weeks
Sengoku BASARA | 3 years
Sengoku BASARA Two | 1 decade
Senki Zesshou Symphogear | 4 months
Senki Zesshou Symphogear AXZ | 4 months
Senki Zesshou Symphogear G | 4 months
Senki Zesshou Symphogear GX | 4 months
Senki Zesshou Symphogear XV | 4 months
Sennen Joyuu | 9 months
Sen no Kiseki Northern War | 1 year
Senpai ga Uzai Kouhai no Hanashi | 1 year
Senryuu Shoujo | 4 years
Sentai Daishikkaku | 6 days
Sentouin, Hakenshimasu! | 2 years
Senyuu | 7 years
Serial Experiments Lain | 3 weeks
Servant x Service | 2 years
Sewayaki Kitsune no Senko-san | 2 years
Sh15uya | 1 year
shadow house | 1 month
Shakugan no Shana | 1 decade
Shakunetsu Kabaddi | 2 years
Shaman King (2021) | 2 years
SHAMAN KING FLOWERS | 3 weeks
Shangri-La Frontier | 2 weeks
Shidonia No Kishi | 9 years
Shidonia No Kishi Daikyuu Wakusei Seneki | 8 years
Shigatsu Wa Kimi No Uso | 5 months
Shigofumi | 1 decade
Shijou Saikyou no Daimaou, Murabito A ni Tensei suru | 1 year
Shijou Saikyou no Deshi Kenichi | 5 years
Shikabane Hime | 5 years
Shiki | 10 months
Shikioriori | 5 years
Shikkakumon no Saikyou Kenja | 2 years
Shimoneta to Iu Gainen ga Sonzai Shinai Taikutsu na Sekai | 5 years
Shinchou Yuusha: Kono Yuusha ga Ore Tueee Kuse ni Shinchou Sugiru | 3 years
Shin Chuuka Ichiban! | 2 years
Shingeki! Kyojin Chuugakkou | 6 years
Shingeki no Bahamut Genesis | 10 months
Shingeki no Kyojin | 2 months
Shingeki no Kyojin OVA | 4 years
Shingeki No Bahamut Virgin Soul | 5 years
Shingeki No Kyojin | 5 months
Shingetsutan Tsukihime | 1 decade
Shin Godzilla 2016 Anno Hideaki | 2 years
Shinigami Bocchan to Kuro Maid | 4 months
Shinigami Bocchan to Kuro Maid 3rd Season | 21 hours
Shinigami no Ballad | 1 decade
SHINKALION Change The World | 6 days
Shin Kamen Rider | 9 months
Shinmai Maou no Testament | 8 months
Shin no Nakama ja Nai to Yuusha no Party wo Oidasareta node, Henkyou de Slow Life suru Koto ni Shimashita | 3 months
Shinrei Tantei Yakumo | 1 decade
Shinryaku! Ika Musume S1 | 1 year
Shinryaku! Ika Musume S2 | 1 year
Shin Sakura Taisen the Animation | 3 years
Shin Seiki GPX Cyber Formula ZERO | 1 decade
Shinsekai Yori | 5 years
Shin Tennis no Ouji-sama | 2 years
Shin Ultraman | 1 year
Shinya! Tensai Bakabon | 5 years
Shin Sekai Yori | 6 years
Shippu! Iron Leaguer | 6 years
Shirobako | 2 years
Shiroi Suna no Aquatope | 2 years
Shirokuma Cafe | 2 years
Shiro Seijo to Kuro Bokushi | 6 months
Shisha no Teikoku | 5 years
Shokei Shoujo no Virgin Road | 1 year
Shokugeki No Souma | 1 month
Shonan Bakusozoku | 5 years
Shoujo Kageki Revue Starlight | 2 years
Shoujo Kakumei Utena | 4 years
Shoujo Shuumatsu Ryokou | 3 years
Shoukoku no Altair | 6 years
Shounen Hollywood -Holly Stage for 49- | 9 years
Shounen Maid | 3 years
Shouwa Genroku Rakugo Shinjuu | 6 months
shugo | 2 months
Shuriken Sentai Ninninger | 5 years
Shuumatsu Nani Shitemasuka Isogashii Desuka Sukutte Moratte Ii Desuka | 5 years
Shuumatsu no Izetta | 5 years
Shuumatsu no Walkure | 9 months
SHY | 4 months
Sidonia no Kishi | 3 years
Sidonia no Kishi Ai Tsumugu Hoshi | 1 year
Silent (Drama) | 1 year
Sirius the Jaeger | 3 years
SK8 the Infinity | 10 months
Sket Dance | 2 years
Skip to Loafer | 9 months
SLAM DUNK | 3 years
Slayers Next | 6 years
Slayers Revolution | 1 decade
Slayers Try | 1 decade
Slayers TV (1995) | 1 year
Slime Taoshite 300-nen, Shiranai Uchi ni Level Max ni Nattemashita | 2 years
Slow Loop | 2 years
Smile PreCure | 5 years
Snack Basue | 3 months
Sokushi Cheat ga Saikyou Sugite, Isekai no Yatsura ga Marude Aite ni Naranai n desu ga. | 3 weeks
Sola | 1 decade
Solo Leveling | 2 months
Somali to Mori no Kamisama | 3 years
Sonic X | 3 years
Sonny Boy | 2 years
Sono Bisque Doll wa Koi wo Suru | 1 month
Sono Hanabira ni Kuchizuke o | 7 years
Sorairo Utility | 2 years
Sora no Aosa wo Shiru Hito yo | 1 week
Sora no Method | 8 years
Sora no Otoshimono | 5 years
Sora no Otoshimono Tokei Jikake no Angeloid | 5 years
Sora no Woto | 1 year
Sora yori mo Tooi Basho | 4 years
Soredemo Ayumu wa Yosetekuru | 1 month
Soredemo Machi wa Mawatteiru | 6 years
Soredemo Sekai wa Utsukushii | 2 years
Sore ga Seiyuu! | 7 years
Sore Ike! Zukkoke Sannin-gumi | 5 years
Sorezore no dangai | 4 years
Soukou Kihei VOTOMS | 5 years
Soukyuu no Fafner | 3 years
Soukyuu No Fafner Exodus | 3 years
Soul land Douluo Dalu | 3 years
Soul Eater | 6 years
Sousei No Onmyouji | 6 years
Sousou no Frieren | 1 week
sousounofuriren | 1 week
Souten Kouro | 1 decade
Space Adventure Cobra | 3 years
Space Dandy | 1 year
Space Runaway Ideon | 5 years
Space Ironmen Kyodyne | 1 decade
Space Pirate Captain Harlock | 4 years
Space Sheriff Gavan | 1 decade
Space Sheriff Shaider | 1 decade
Special Rescue Exceedraft | 9 years
Special Rescue Police Winspector | 1 decade
Spice and Wolf | 9 months
Spice and Wolf: MERCHANT MEETS THE WISE WOLF (Ookami to Koushinryou) | 4 days
Spice and Wolf II | 1 decade
Spirited Away (Sen to Chihiro no Kamikakushi) | 4 years
Spirit of Wonder | 1 decade
Spriggan (ONA) | 8 months
SPYFAMILY | 6 months
SPYFAMILY Season 2 | 3 months
SPY ROOM | 5 months
Spy x Family Part 2 | 1 year
SSSS.Dynazenon | 11 months
SSSS.Gridman | 11 months
Stand My Heroes: Piece of Truth | 4 years
Starmyu | 5 years
Starry Sky | 9 years
Starry Tales | 1 decade
Star Twinkle Precure | 4 years
Star Wars Visions | 1 year
Star Driver | 1 year
Star Wars Clone Wars | 1 decade
Steamboy | 5 months
Stein;Gate | 5 months
Steins;Gate 0 | 1 year
Stitch! Zutto Saikou no Tomodachi | 1 decade
Strike the Blood | 3 years
Strike Witches | 5 years
Subarashiki Kono Sekai The Animation | 2 years
Sugar Apple Fairy Tale | 7 months
Suisei no Gargantia | 5 years
Suite PreCure | 5 years
Suki-tte ii na yo. | 5 years
Suki na Ko ga Megane wo Wasureta | 6 months
Summer Time Rendering | 1 year
Summer Wars | 2 years
Suntory Minami Alps no Tennensui x Kimi no Na wa. | 7 years
Super Crooks | 2 years
Super Cub | 1 month
Super Dimension Fortress Macross | 5 years
Super Dimension Fortress Macross II - Lovers Again | 5 years
Super Lovers | 7 years
Super Rescue Solbrain | 1 decade
Super Robot Lifeform Transformers Prime | 1 decade
Suzume no Tojimari | 2 months
Suzumiya Haruhi no Shoushitsu | 3 years
Suzumiya Haruhi no Yuuutsu | 2 years
Sword | 4 years
Sword Art Online | 5 months
Sword Art Online: Alicization | 3 years
Sword Art Online Alternative Gun Gale Online | 4 years
Sword Art Online II | 5 months
Sword Art Online Ordinal Scale | 2 years
Sword Art Online the Movie Progressive - Aria of a Starless Night | 1 year
SWORD GAI The Animation | 5 years
Synduality: Noir | 3 weeks
Tachiguishi Retsuden | 2 years
Tada-kun wa Koi wo Shinai | 3 years
Taimadou Gakuen 35 Shiken Shoutai | 4 years
Taishou Yakyuu Musume | 7 years
Taisou Zamurai | 2 years
Taiyou no Kiba Dougram | 5 years
Taiyou Sentai Sul Vulcan | 1 year
takt op.Destiny | 2 years
Tales of the Abyss | 1 decade
Tales of Zestiria the X | 4 years
Tales of Zestiria ~Doushi no Yoake~ | 9 years
Tales From Earthsea | 4 years
Tamako Love Story | 4 years
Tamako Market | 2 years
Tamayura~ Hitotose~ | 9 years
Tanaka-kun wa Itsumo Kedaruge | 3 years
Tanken Driland | 1 decade
Tanken Driland 1000-nen No Mahou | 1 decade
Tantei wa Mou, Shindeiru. | 2 years
Tari Tari | 3 years
Tasogare Otome × Amnesia | 1 decade
Tatakau Shisho - The Book of Bantorra | 6 years
Tatami Galaxy ( Yojouhan Shinwa Taikei) | 1 month
Tate no Yuusha no Nariagari | 5 months
Tate no Yuusha no Nariagari S2 | 9 months
Tate no Yuusha no Nariagari S3 | 3 months
Tawawa on Monday | 7 years
Tearmoon Teikoku Monogatari | 3 weeks
TECHNOROID: OVERMIND | 9 months
Tegami Bachi | 5 years
Tegami Bachi Reverse | 1 decade
Teikou Pengin (Youtube) | 2 years
Tekkon Kinkreet | 4 months
Telepathy Shoujo Ran | 1 decade
TenchiMuyo | 1 decade
Tengen Toppa Gurren Lagann | 4 years
Tengoku | 3 weeks
Tengoku Daimakyou | 9 months
Tenkai Knights | 9 years
Tenki No Ko | 3 years
Tenki no Ko | 8 months
Tenkuu no Shiro Rapyuta | 1 decade
Tenkuu Shinpan | 5 months
Tennis no Ouji-sama - The Prince of Tennis | 2 years
TenPuru | 7 months
Tenrou: Sirius the Jaeger | 5 years
Tensai Ouji no Akaji Kokka Saisei Jutsu | 5 months
tensei | 6 months
Tensei jo to Tensai Reij no Mah Kakumei | 1 year
Tensei Kenja no Isekai Life | 1 year
Tensei Kizoku, Kantei Skill de Nariagaru | 2 days
Tensei Kizoku no Isekai Boukenroku | 10 months
Tensei Oujo to Tensai Reijou no Mahou Kakumei | 1 year
Tensei Shitara Dai Nana Ouji | 4 days
Tensei Shitara Ken Deshita | 1 month
Tensei Shitara Slime Datta Ken S3 | 22 hours
Tensei Shitara Slime Datta Ken Tensei Shitara Slime Datta Ken 2nd Season | 2 years
Tensei Shitara Slime Datta Ken | 1 year
Tenshi no 3P! | 5 years
Tensou Sentai Goseiger | 1 decade
Tensura Nikki: Tensei shitara Slime Datta Ken | 2 years
Terra e | 2 years
Terra Formars | 5 years
Tezuka Osamu Monogatari: Boku wa Songoku | 1 decade
Tezuka Osamu no Buddha | 9 years
The Big O | 5 years
The Fable | 1 week
The First Slam Dunk | 1 week
The Five Star Stories | 1 decade
The God of High School | 3 years
THE IDOLM@STER (IdolMaster) | 1 year
The iDOLM@STER Cinderella Girls | 5 years
THE iDOLM@STER Cinderella Girls U149 | 8 months
The iDOLM@STER Million Live! | 3 months
THE iDOLM@STER SHINY COLORS | 2 days
The Laughing Salesman | 6 years
The Laws of the Universe Part 0 +Part 1 Japan PGS | 4 years
The Mystical Laws | 1 decade
THE NEW GATE | 2 days
The Orbital Children | 2 years
Thermae Romae | 3 years
The Rolling Girls | 5 years
The Secret World of Arrietty | 3 years
The Sky Crawlers | 4 years
The Snack World | 3 years
The Spiriting Away of Sen and Chihiro | 8 months
The Star of Cottonland | 7 years
The Ultraman: Jackal vs. Ultraman | 6 years
The Virgin Psychics | 3 years
The Borrower Arrietty | 9 years
The Kagestar | 1 year
The Return Of Ultraman | 1 decade
The Twelve Kingdoms | 3 months
Thunderbolt Fantasy | 6 years
Tiger & Bunny | 1 year
Time Bokan 24 | 6 years
Time Travel Shoujo | 7 years
Toaru Kagaku no Accelerator | 2 years
Toaru Kagaku no Railgun | 4 years
Toaru Kagaku no Railgun S | 5 years
Toaru Kagaku no Railgun T | 3 years
Toaru Majutsu no Index | 3 years
Toaru Majutsu no Index II | 5 years
Toaru Majutsu no Index III | 3 years
Toaru Majutsu no Index Movie - Endymion no Kiseki | 2 years
Toaru Ossan no VRMMO Katsudouki | 3 months
Tokimeki Memorial | 1 decade
Tokimeki Tonight | 4 years
Toki no Tabibito - Time Stranger | 9 years
Toki o Kakeru Shoujo | 10 months
Tokubetsu-hen Hibike! Euphonium: Ensemble Contest | 8 months
Tokumei Sentai Go-Busters | 1 decade
Tokurei Sochi Dantai Stella Jo-Gakuin Koutou-ka C3-bu | 1 decade
Tokusatsu GaGaGa | 4 years
Tokusou Sentai Dekaranger 2005 Resynced | 2 years
Tokusou Robo Janperson | 9 years
Tokusou Sentai Dekaranger | 5 years
Tokyo 24-ku | 1 year
Tokyo Ghoul | 10 months
Tokyo Ghoul:Re | 3 years
Tokyo Ghoul A | 10 months
Tokyo Ghoul OVA | 5 years
Tokyo Godfathers | 9 months
Tokyo Magnitude 8.0 | 2 years
Tokyo Marble Chocolate | 1 decade
Tokyo Mew Mew New | 1 year
Tokyo Mew Mew New 2nd Season | 9 months
Tokyo Ravens | 7 years
Tokyo Revengers | 1 year
Tokyo Revengers: Seiya Kessen Hen | 1 year
Tokyo Revengers: Tenjiku-hen | 3 months
To Love-Ru | 5 years
To Love-Ru Darkness | 4 years
Tomica Hero Rescue Force | 5 months
Tomo-chan wa Onnanoko! | 11 months
Tomodachi Game | 1 year
Tonari no Kaibutsu-kun | 4 years
Tonari no Seki-kun | 9 years
Tonari no Totoro | 1 year
Tonari no Youkai-san | 4 days
Tondemo Skill de Isekai Hourou Meshi | 9 months
Tonikaku Kawaii | 10 months
Tonikaku Kawaii 2nd Season | 9 months
Tonikaku Kawaii Joshikou-hen | 8 months
Top o Nerae! GunBuster | 3 years
Toradora! | 1 month
Toriko | 5 years
Toshokan Sensou - Kakumei no Tsubasa | 1 decade
Totsuzen kekkon | 4 years
Touch | 4 years
Touhai Densetsu Akagi - Yami Ni Maiorita Tensai | 2 years
Touhou | 4 years
Touken Ranbu: Hanamaru | 5 years
Train Heroes | 1 decade
Tribe Cool Crew | 8 years
TRIGUN | 5 years
TRIGUN Stamped | 9 months
Trinity Blood | 1 decade
Trinity Seven | 5 years
Tropical-Rouge! Precure | 2 years
Tsubasa Chronicle | 9 years
Tsubasa Shunraiki | 1 decade
Tsubasa Tokyo Revelations | 1 decade
Tsugumomo | 5 years
Tsuki ga Kirei | 1 year
Tsuki ga Michibiku Isekai Douchuu | 22 hours
Tsukimonogatari | 2 years
Tsundere Akuyaku Reij Rzerotte | 1 month
Tsuredure Children | 3 years
Tsuritama | 2 years
Tsurune Kazemai Koukou Kyuudou Bu | 1 year
Tsuujou Kougeki ga Zentai Kougeki de Ni-kai Kougeki no Okaasan wa Suki Desu ka? | 4 years
TthJ',()),).)" | 2 months
TthJ'LuvSWU<'">MEDUso | 2 months
TthJ | 2 months
Turn A Gundam | 1 year
Twin Angel Break | 5 years
Uchiage Hanabi (2017) | 3 years
Uchi no Kaisha no Chiisai Senpai no Hanashi | 6 months
Uchouten Kazoku | 5 years
Uchuu no Stellvia | 5 years
Uchuu Senkan Tiramisu | 5 years
Uchuu Senkan Tiramisu II | 5 years
Uchuu Show e Youkoso | 1 decade
Uchuu Keiji Shaider | 2 years
Uchuu Keiji Sharivan | 9 years
Uchuu Kyoudai | 3 years
Uchuu Senkan Yamato | 2 years
Uchuu Senkan Yamato 2 | 1 decade
Uchuu Senkan Yamato 3 | 1 decade
Uchuu Senkan Yamato 2199 | 3 years
Uchuu Senkan Yamato 2202 | 2 years
Uchuu Sentai Kyuuranger | 4 years
Ueno-san wa Bukiyou | 5 years
UFO Robot Grendizer | 9 years
UlhsalNBPT0= | 4 months
UlhsalNDa3NMaWtvTENjb0lpND0= | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1EazBPUzhxSVRBd01EQXdMeW9oTXpBNU1qaFZUa2xQVGk4cUtpOUJiRXd2S2lvdlUyVnNaV04wTHlvcUwwNTFiR3dzVG5Wc2JDeE9kV3hzTEU1MWJHd3NUblZzYkN4T2RXeHNMRTUxYkd3c1RuVnNiQ292S2k4cUx5b3ZMUzB2S2lvdlJFRjFRdz09 | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1ERXlNUzhxSVRBd01EQXdMeW9oTXpBeU1qaFZUa2xQVGk4cUtpOUJiRXd2S2lvdmMyVk1SV05VTHlvcUwyNTFURXdxTHlvdktpOHFMeTB0THlvcUwxVlJiblU9 | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1ERXlOeThxSVRBd01EQXdMeW9oTXpBM09UQlZUa2xQVGk4cUtpOWhiRXd2S2lvdmMyVnNaVU5VTHlvcUwyNVZiR3dzYmxWc2JDeHVWV3hzTEc1VmJHd3NibFZzYkN4dVZXeHNMRzVWYkd3c2JsVnNiQ3h1Vld4c0tpOHFMeW92S2k4dExTOHFLaTlKUkdwcg== | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1ESTNNQzhxSVRBd01EQXdMeW9oTXpBek5ESlZUa2xQVGk4cUtpOUJUR3d2S2lvdmMwVk1aVU4wTHlvcUwyNVZURXdzYmxWTVRDeHVWVXhNTEc1VlRFd3NibFZNVENvdktpOHFMeW92TFMwdktpb3ZlbWxMU3c9PQ== | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1ETXlOQzhxSVRBd01EQXdMeW9oTXpBME9UUlZUa2xQVGk4cUtpOUJiR3d2S2lvdlUwVk1SV05VTHlvcUwwNTFURXdzVG5WTVRDeE9kVXhNTEU1MVRFd3NUblZNVEN4T2RVeE1MRTUxVEV3c1RuVk1UQ3hPZFV4TUxFNTFURXdxTHlvdktpOHFMeTB0THlvcUwySjFiM0k9 | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1EVXhPUzhxSVRBd01EQXdMeW9oTXpBNE9UUlZUa2xQVGk4cUtpOWhURXd2S2lvdlUwVnNSVU4wTHlvcUwwNVZiR3dzVGxWc2JDeE9WV3hzS2k4cUx5b3ZLaTh0TFM4cUtpOTBVVmxQ | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1EWTVOQzhxSVRBd01EQXdMeW9oTXpBNU5EbFZUa2xQVGk4cUtpOWhUR3d2S2lvdlUyVnNaV04wTHlvcUwwNVZUR3dzVGxWTWJDeE9WVXhzTEU1VlRHd3FMeW92S2k4cUx5MHRMeW9xTDBSSVFYST0= | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1EWXdOQzhxSVRBd01EQXdMeW9oTXpBM05USlZUa2xQVGk4cUtpOWhUR3d2S2lvdmMyVk1SV04wTHlvcUwyNVZiR3dzYmxWc2JDeHVWV3hzTEc1VmJHd3NibFZzYkN4dVZXeHNLaThxTHlvdktpOHRMUzhxS2k5VGNtUlc= | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1EY3lPQzhxSVRBd01EQXdMeW9oTXpBeU5UZFZUa2xQVGk4cUtpOWhiRXd2S2lvdlUyVnNSV05VTHlvcUwwNVZiR3dzVGxWc2JDeE9WV3hzTEU1VmJHd3NUbFZzYkN4T1ZXeHNMRTVWYkd3cUx5b3ZLaThxTHkwdEx5b3FMMU5qV0dRPQ== | 4 months
UlhsalNDa3ZLaW92THlvaE1EQXdNREF2S2lFek1EYzRPUzhxSVRBd01EQXdMeW9oTXpBMk56TlZUa2xQVGk4cUtpOUJiR3d2S2lvdlUyVnNaVU4wTHlvcUwwNTFiR3dzVG5Wc2JDb3ZLaThxTHlvdkxTMHZLaW92VFVOcFZnPT0= | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd01qQTNMeW9oTURBd01EQXZLaUV6TURnd01GVk9TVTlPTHlvcUwyRnNUQzhxS2k5VFJXeEZRMVF2S2lvdmJuVk1iQ3h1ZFV4c0xHNTFUR3dzYm5WTWJDeHVkVXhzTEc1MVRHd3NiblZNYkNvdktpOHFMeW92TFMwdktpb3ZZMDFoVVE9PQ== | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd01USXpMeW9oTURBd01EQXZLaUV6TURVek5GVk9TVTlPTHlvcUwwRnNiQzhxS2k5elpXeEZZM1F2S2lvdlRsVnNiQ292S2k4cUx5b3ZMUzB2S2lvdmVGaFhUQT09 | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd01UWXdMeW9oTURBd01EQXZLaUV6TURRd05GVk9TVTlPTHlvcUwwRnNiQzhxS2k5VFJXeGxZM1F2S2lvdlRuVk1iQ3hPZFV4c0xFNTFUR3dzVG5WTWJDeE9kVXhzTEU1MVRHd3NUblZNYkN4T2RVeHNMRTUxVEd3cUx5b3ZLaThxTHkwdEx5b3FMMFp3UldjPQ== | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd016QTBMeW9oTURBd01EQXZLaUV6TURjME1sVk9TVTlPTHlvcUwwRnNUQzhxS2k5elJXeGxZM1F2S2lvdmJsVk1iQ3h1VlV4c0xHNVZUR3dxTHlvdktpOHFMeTB0THlvcUwybDNaVlk9 | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd016VTBMeW9oTURBd01EQXZLaUV6TURNek1WVk9TVTlPTHlvcUwwRnNiQzhxS2k5VFJVeEZZMVF2S2lvdlRsVnNUQ3hPVld4TUxFNVZiRXdzVGxWc1RDeE9WV3hNTEU1VmJFd3NUbFZzVEN4T1ZXeE1MRTVWYkV3c1RsVnNUQ292S2k4cUx5b3ZMUzB2S2lvdmJrcHFTZz09 | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd016VXlMeW9oTURBd01EQXZLaUV6TURnek1GVk9TVTlPTHlvcUwyRnNUQzhxS2k5VFJVeEZZMVF2S2lvdmJuVnNUQ3h1ZFd4TUxHNTFiRXdzYm5Wc1RDeHVkV3hNS2k4cUx5b3ZLaTh0TFM4cUtpOUtWSFZw | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd05ESTNMeW9oTURBd01EQXZLaUV6TURreE1WVk9TVTlPTHlvcUwyRk1iQzhxS2k5VFpXeGxRM1F2S2lvdlRsVk1iQ3hPVlV4c0xFNVZUR3dxTHlvdktpOHFMeTB0THlvcUwwRmpUWGs9 | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd05EUTNMeW9oTURBd01EQXZLaUV6TURZM05WVk9TVTlPTHlvcUwyRk1iQzhxS2k5VFJVeGxZMVF2S2lvdlRuVk1UQ3hPZFV4TUxFNTFURXdzVG5WTVRDeE9kVXhNTEU1MVRFd3NUblZNVENvdktpOHFMeW92TFMwdktpb3ZSa3gzWmc9PQ== | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd05UQTRMeW9oTURBd01EQXZLaUV6TURRNU4xVk9TVTlPTHlvcUwwRk1iQzhxS2k5elJVeEZRMVF2S2lvdmJsVnNiQ3h1Vld4c0xHNVZiR3dzYmxWc2JDb3ZLaThxTHlvdkxTMHZLaW92Ymxsa1dnPT0= | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd05USTVMeW9oTURBd01EQXZLaUV6TURNME1WVk9TVTlPTHlvcUwwRnNUQzhxS2k5elJVeEZRM1F2S2lvdmJsVnNUQ3h1Vld4TUtpOHFMeW92S2k4dExTOHFLaTlCV2t4RA== | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd05UVXpMeW9oTURBd01EQXZLaUV6TURnME1WVk9TVTlPTHlvcUwwRnNUQzhxS2k5elJXeGxRMVF2S2lvdmJsVnNiQ3h1Vld4c0xHNVZiR3dzYmxWc2JDeHVWV3hzTEc1VmJHd3FMeW92S2k4cUx5MHRMeW9xTDJoS2Nsbz0= | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd056UTJMeW9oTURBd01EQXZLaUV6TURrME4xVk9TVTlPTHlvcUwwRnNiQzhxS2k5VFJVeGxZM1F2S2lvdlRuVnNiQ3hPZFd4c0xFNTFiR3dzVG5Wc2JDb3ZLaThxTHlvdkxTMHZLaW92VFU1RmNBPT0= | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd056WTRMeW9oTURBd01EQXZLaUV6TURVek5WVk9TVTlPTHlvcUwwRnNUQzhxS2k5elJXeGxRMVF2S2lvdlRsVnNUQ3hPVld4TUxFNVZiRXdzVGxWc1RDeE9WV3hNTEU1VmJFd3NUbFZzVEN4T1ZXeE1LaThxTHlvdktpOHRMUzhxS2k5TVpWaFU= | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd056YzFMeW9oTURBd01EQXZLaUV6TURNd09WVk9TVTlPTHlvcUwwRnNiQzhxS2k5VFpXeEZRM1F2S2lvdmJuVnNUQ3h1ZFd4TUxHNTFiRXdzYm5Wc1RDeHVkV3hNTEc1MWJFd3NiblZzVEN4dWRXeE1MRzUxYkV3c2JuVnNUQ292S2k4cUx5b3ZMUzB2S2lvdlZHVk5WUT09 | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd09Ea3hMeW9oTURBd01EQXZLaUV6TURneU1WVk9TVTlPTHlvcUwwRnNUQzhxS2k5VFpVeGxZM1F2S2lvdlRsVnNUQ3hPVld4TUxFNVZiRXdzVGxWc1RDeE9WV3hNTEU1VmJFd3NUbFZzVEN4T1ZXeE1MRTVWYkV3cUx5b3ZLaThxTHkwdEx5b3FMMEpRZWxFPQ== | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd09EVTNMeW9oTURBd01EQXZLaUV6TURVeE5WVk9TVTlPTHlvcUwwRnNiQzhxS2k5VFpVeGxZMVF2S2lvdlRsVk1iQ3hPVlV4c0xFNVZUR3dzVGxWTWJDeE9WVXhzTEU1VlRHd3FMeW92S2k4cUx5MHRMeW9xTDJwNFJVYz0= | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd09EZzVMeW9oTURBd01EQXZLaUV6TURVek5WVk9TVTlPTHlvcUwyRk1UQzhxS2k5elJXeGxZMVF2S2lvdmJuVk1iQ292S2k4cUx5b3ZMUzB2S2lvdlVtdHlaUT09 | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd09USXdMeW9oTURBd01EQXZLaUV6TURjNE1WVk9TVTlPTHlvcUwwRnNiQzhxS2k5elJXeEZZM1F2S2lvdmJsVk1iQ3h1VlV4c0xHNVZUR3dzYmxWTWJDeHVWVXhzTEc1VlRHd3NibFZNYkN4dVZVeHNLaThxTHlvdktpOHRMUzhxS2k5RFNXdGg= | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd09UUTJMeW9oTURBd01EQXZLaUV6TURNNE1WVk9TVTlPTHlvcUwyRk1UQzhxS2k5elJXeGxRMVF2S2lvdlRuVk1iQ3hPZFV4c0xFNTFUR3dzVG5WTWJDeE9kVXhzS2k4cUx5b3ZLaTh0TFM4cUtpOWtZVVZy | 4 months
UlhsalNDOHFLaTh2S2lFd01EQXdNQzhxSVRNd09UZzFMeW9oTURBd01EQXZLaUV6TURRM00xVk9TVTlPTHlvcUwyRk1iQzhxS2k5VFJXeEZRM1F2S2lvdlRsVnNiQ3hPVld4c0tpOHFMeW92S2k4dExTOHFLaTlxWjFSRA== | 4 months
UlhsalNDY3BMeW9xTHk4cUlUQXdNREF3THlvaE16QTJOalV2S2lFd01EQXdNQzhxSVRNd05URTBUMUpFUlZJdktpb3ZRbmt2S2lvdk1Tb3ZLaThxTHlvdkxTMHZLaW92VVdsR1l3PT0= | 4 months
UlhsalNDY3BMeW9xTHk4cUlUQXdNREF3THlvaE16QTNNelF2S2lFd01EQXdNQzhxSVRNd016VTVUMUpFUlZJdktpb3ZZbGt2S2lvdk9URXpNaW92S2k4cUx5b3ZMUzB2S2lvdmRXSmtiQT09 | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1Ea3lNeThxSVRBd01EQXdMeW9oTXpBek1ESlZUa2xQVGk4cUtpOUJiRXd2S2lvdmMwVk1SVU5VTHlvcUwyNVZiR3dxTHlvdktpOHFMeTB0THlvcUwycDZSRk09 | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1ESTRPQzhxSVRBd01EQXdMeW9oTXpBM016QlBVa1JGVWk4cUtpOUNlUzhxS2k4eU1Db3ZLaThxTHlvdkxTMHZLaW92UWtsbFVBPT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1ESXpNQzhxSVRBd01EQXdMeW9oTXpBeE9USlZUa2xQVGk4cUtpOWhURXd2S2lvdmMwVk1SV04wTHlvcUwyNVZiRXdzYmxWc1RDeHVWV3hNS2k4cUx5b3ZLaTh0TFM4cUtpOUZZMnB5 | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1ETXlOQzhxSVRBd01EQXdMeW9oTXpBNE5UWlBVa1JGVWk4cUtpOUNlUzhxS2k4MU1Db3ZLaThxTHlvdkxTMHZLaW92YW0xYVJ3PT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1ETXpOeThxSVRBd01EQXdMeW9oTXpBME5USlZUa2xQVGk4cUtpOUJiR3d2S2lvdlUyVk1aVU4wTHlvcUwwNTFiRXdzVG5Wc1RDeE9kV3hNTEU1MWJFd3NUblZzVEN4T2RXeE1MRTUxYkV3c1RuVnNUQ292S2k4cUx5b3ZMUzB2S2lvdldGTjRaUT09 | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EUTFOQzhxSVRBd01EQXdMeW9oTXpBeU5USlZUa2xQVGk4cUtpOWhiRXd2S2lvdlUyVnNaV05VTHlvcUwyNTFiRXdzYm5Wc1RDeHVkV3hNTEc1MWJFd3NiblZzVEN4dWRXeE1LaThxTHlvdktpOHRMUzhxS2k5dlJHNU4= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EUTFOQzhxSVRBd01EQXdMeW9oTXpBNE9EQlBVa1JGVWk4cUtpOWlXUzhxS2k4ME1Db3ZLaThxTHlvdkxTMHZLaW92WVVSS1dnPT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EUTJNaThxSVRBd01EQXdMeW9oTXpBeE5qRlZUa2xQVGk4cUtpOUJUR3d2S2lvdmMwVk1SVU5VTHlvcUwwNVZUR3dzVGxWTWJDeE9WVXhzTEU1VlRHd3NUbFZNYkN4T1ZVeHNMRTVWVEd3cUx5b3ZLaThxTHkwdEx5b3FMMDVKUlV3PQ== | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EUTRNUzhxSVRBd01EQXdMeW9oTXpBMU5EVlZUa2xQVGk4cUtpOWhUR3d2S2lvdmMwVnNSV04wTHlvcUwwNTFiRXdzVG5Wc1RDeE9kV3hNTEU1MWJFd3NUblZzVENvdktpOHFMeW92TFMwdktpb3ZXV2hvVkE9PQ== | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EUXdOUzhxSVRBd01EQXdMeW9oTXpBMk1qSlZUa2xQVGk4cUtpOWhUR3d2S2lvdlUwVk1SV05VTHlvcUwyNTFiRXdzYm5Wc1RDeHVkV3hNTEc1MWJFd3NiblZzVEN4dWRXeE1MRzUxYkV3c2JuVnNUQ3h1ZFd4TUxHNTFiRXdxTHlvdktpOHFMeTB0THlvcUwxbEhkV289 | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EVTBOaThxSVRBd01EQXdMeW9oTXpBek9UbFBVa1JGVWk4cUtpOUNlUzhxS2k4Mk1Db3ZLaThxTHlvdkxTMHZLaW92U2toMlJBPT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EVTVOQzhxSVRBd01EQXdMeW9oTXpBeE5UbFBVa1JGVWk4cUtpOUNlUzhxS2k4ek1Db3ZLaThxTHlvdkxTMHZLaW92ZFVadVVRPT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EWTBOeThxSVRBd01EQXdMeW9oTXpBM09UaFBVa1JGVWk4cUtpOUNlUzhxS2k4Mk55b3ZLaThxTHlvdkxTMHZLaW92UTNSbVRRPT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EWTNPQzhxSVRBd01EQXdMeW9oTXpBM09UaFBVa1JGVWk4cUtpOUNlUzhxS2k4eE1Db3ZLaThxTHlvdkxTMHZLaW92Y0d0RmVRPT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EWTVNUzhxSVRBd01EQXdMeW9oTXpBMU5UQlBVa1JGVWk4cUtpOWlXUzhxS2k4Mk5Tb3ZLaThxTHlvdkxTMHZLaW92Y0VkbWFBPT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EWTVPQzhxSVRBd01EQXdMeW9oTXpBNE56TlZUa2xQVGk4cUtpOUJiRXd2S2lvdmMwVnNSVU4wTHlvcUwyNVZiRXdzYmxWc1RDeHVWV3hNTEc1VmJFd3FMeW92S2k4cUx5MHRMeW9xTDJOeVFraz0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EY3hOUzhxSVRBd01EQXdMeW9oTXpBeE9EQlZUa2xQVGk4cUtpOWhiRXd2S2lvdmMwVnNaVU5VTHlvcUwyNTFURXdzYm5WTVRDb3ZLaThxTHlvdkxTMHZLaW92ZWxOVlNBPT0= | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EY3lOUzhxSVRBd01EQXdMeW9oTXpBeE1UaFBVa1JGVWk4cUtpOWlXUzhxS2k4eEtpOHFMeW92S2k4dExTOHFLaTlPY0dGTQ== | 4 months
UlhsalNDY3ZLaW92THlvaE1EQXdNREF2S2lFek1EZ3lOUzhxSVRBd01EQXdMeW9oTXpBME5qZFZUa2xQVGk4cUtpOWhiRXd2S2lvdmMwVnNSV04wTHlvcUwwNVZiRXdzVGxWc1RDeE9WV3hNTEU1VmJFd3NUbFZzVEN4T1ZXeE1MRTVWYkV3c1RsVnNUQ3hPVld4TUtpOHFMeW92S2k4dExTOHFLaTlHVlZCMA== | 4 months
UlhsalNDZDNjSEJCUldZOEp5SStXVU5IYlhCRw== | 4 months
Ultimate Spider-Man VS Sinister Six | 7 years
Ultimate Spiderman Web Warriors | 8 years
ULTRA GALAXY FIGHT:NEW GENERATION HEROES | 4 years
ULTRAMAN | 5 years
Ultraman Geed | 5 years
Ultraman New Generation Stars 2 | 1 month
Ultraman Orb | 7 years
Ultraman Taiga | 4 years
Ultraman Z | 3 years
Ultraman Blazer | 3 months
Ultraman Chronicle D | 1 year
Ultraman Chronicle Z Heroes Odyssey | 2 years
Ultraman Decker | 1 year
Ultraman Ginga | 9 years
Ultraman Ginga S | 5 years
Ultraman New Generation Cronicle | 4 years
Ultraman New Generation Stars | 1 week
Ultraman Orb | 6 years
Ultraman Retsuden | 1 decade
Ultraman R B | 5 years
Ultraman Trigger | 2 years
Ultraman X | 7 years
Ultraman Zero The Chronicle | 6 years
Uma Musume Pretty Derby | 3 months
Umibe no etranger | 2 years
Umi ga Kikoeru | 3 years
Un-Go | 1 decade
Undead Girl Murder Farce | 5 months
Undead Unluck | 3 weeks
Under Ninja | 3 months
Uninhabited Planet Survive | 1 decade
UniteUp! | 9 months
Unnamed Memory | 4 days
UQ Holder! Mahou Sensei Negima! 2 | 5 years
Uragiri wa Boku no Namae o Shitte Iru | 9 years
Uramichi Onii-san | 9 months
Urara Meirochou | 2 years
Urasekai Picnic | 3 years
Urusei Yatsura (2022) | 9 months
Urusei Yatsura (2022) 2nd Season | 1 day
Urusei Yatsura | 1 month
us | 5 months
Usagi Drop | 2 years
Ushio to Tora | 6 years
Ushio to Tora 2 | 6 years
Utawarerumono | 4 years
Utawarerumono: Itsuwari no Kamen | 5 years
Uzaki-chan wa Asobitai! | 1 year
Vampire Dormitory | 4 days
Vampire in the Garden | 1 year
Vangua-Road | 1 decade
Vanguard TV TRY | 1 decade
Vanitas no Karte | 1 year
Vinland Saga | 3 weeks
Violet Evergarden | 7 months
Violet Evergarden Movie | 1 month
Vivy -Fluorite Eye's Song | 2 years
Waccha Primagi! | 1 year
Wagaya no Oinari-sama | 1 decade
Wakaokami wa Shougakusei! | 6 years
Wakaokami wa Shougakusei! movie | 4 years
Wandering Witch: The Journey of Elaina | 2 years
Warau Salesman | 5 years
Warau Salesman New | 5 years
Watashi ga Motenai no wa Dou Kangaetemo Omaera ga Warui! | 3 years
Watashi ni Tenshi ga Maiorita! | 1 year
Watashi no Oshi wa Akuyaku Reijou. | 2 months
Watashi no Shiawasena Kekkon () | 7 months
Watashi no Yuri wa Oshigoto desu! | 9 months
Watashi Ga Motete Dou Sunda | 6 years
WATATEN! An Angel Flew Down to Me | 4 years
Whisper of the Heart | 4 years
White Album 2 | 1 year
why | 1 week
Wicked City | 1 year
WIND BREAKER | 1 day
Wonder Egg Priority | 2 years
WonderfulPrecure | 6 days
Words Bubble Up Like Soda Pop | 2 years
World Dai Star | 10 months
World Trigger | 2 years
Wotaku ni Koi wa Muzukashii | 3 years
Xam'd Lost Memories (Bounen no Zamudo) | 8 years
xOCT');SELEct DBMS PIPE.reCeiVE MEssaGE(ChR(105)||ChR(84)||ChR(67)||ChR(73),5) frOm dUAl-- | 4 months
xOCT');SELecT Pg SLEep(5)-- | 4 months
xOCT');WAITFOR DELAY '0:0:5'-- | 4 months
xOCT') And (Select 2192 fROm (Select(SleEp(5)))fkMO) And ('QyMM'='QyMM | 4 months
xOCT') AnD 2390 iN (selEct (chAr(113)+chAr(113)+chAr(122)+chAr(107)+chAr(113)+(selEct (casE When (2390=2390) tHEn chAr(49) eLsE chAr(48) eNd))+chAr(113)+chAr(120)+chAr(98)+chAr(122)+chAr(113))) AnD ('LrTw'='LrTw | 4 months
xOCT') ANd 4927=(SeLECt uPPER(xMLtypE(chR(60)||chR(58)||chR(113)||chR(113)||chR(122)||chR(107)||chR(113)||(SeLECt (CaSe WHEn (4927=4927) THeN 1 ELse 0 End) FROm DUaL)||chR(113)||chR(120)||chR(98)||chR(122)||chR(113)||chR(62))) FROm DUaL) ANd ('oDPg'='oDPg | 4 months
xOCT') And 6185=CAst((CHr(113)||CHr(113)||CHr(122)||CHr(107)||CHr(113))||(sElect (cASe wHen (6185=6185) THEn 1 elsE 0 ENd))::teXT||(CHr(113)||CHr(120)||CHr(98)||CHr(122)||CHr(113)) As nuMerIc) And ('BStL'='BStL | 4 months
xOCT') aND 8091=1318 aND ('MtoC'='MtoC | 4 months
xOCT') aND EXtRaCtValue(3620,CoNcaT(0x5c,0x71717a6b71,(selECT (ELt(3620=3620,1))),0x7178627a71)) aND ('eiyG'='eiyG | 4 months
xOCT';SEleCt DBMS PIPE.ReCeiVE meSsAge(cHR(105)||cHR(84)||cHR(67)||cHR(73),5) fROM dUAl-- | 4 months
xOCT';seleCt pg Sleep(5)-- | 4 months
xOCT';WAITFOR DELAY '0:0:5'-- | 4 months
xOCT' anD (seLeCT 2192 fROM (seLeCT(SlEEP(5)))fkMO) anD 'QRYc'='QRYc | 4 months
xOCT' AnD 2390 In (seLECT (cHAR(113)+cHAR(113)+cHAR(122)+cHAR(107)+cHAR(113)+(seLECT (caSE wHen (2390=2390) theN cHAR(49) elSE cHAR(48) End))+cHAR(113)+cHAR(120)+cHAR(98)+cHAR(122)+cHAR(113))) AnD 'qeAH'='qeAH | 4 months
xOCT' ANd 4927=(sElecT UppER(xmLtYPE(Chr(60)||Chr(58)||Chr(113)||Chr(113)||Chr(122)||Chr(107)||Chr(113)||(sElecT (cASE wHeN (4927=4927) THEn 1 ELsE 0 ENd) FrOm dUAl)||Chr(113)||Chr(120)||Chr(98)||Chr(122)||Chr(113)||Chr(62))) FrOm dUAl) ANd 'HXbD'='HXbD | 4 months
xOCT' aND 6185=cAST((cHr(113)||cHr(113)||cHr(122)||cHr(107)||cHr(113))||(sELect (CAse whEN (6185=6185) THen 1 elsE 0 eNd))::texT||(cHr(113)||cHr(120)||cHr(98)||cHr(122)||cHr(113)) As NuMERic) aND 'QWsb'='QWsb | 4 months
xOCT' And 9704=5258 And 'MekD'='MekD | 4 months
xOCT' ANd eXtrACTvalUE(3620,conCat(0x5c,0x71717a6b71,(selEct (eLt(3620=3620,1))),0x7178627a71)) ANd 'xUAB'='xUAB | 4 months
xOCT'cEKBfe<'">aEMHSr | 4 months
xOCT))(.,)'"(( | 4 months
xOCT);SElECT DBMS PIPE.ReceIVe MesSage(Chr(105)||Chr(84)||Chr(67)||Chr(73),5) FROm duAL-- | 4 months
xOCT);SelEcT pg SLEEP(5)-- | 4 months
xOCT);WAITFOR DELAY '0:0:5'-- | 4 months
xOCT) ANd (sElecT 2192 frOm (sElecT(SleeP(5)))fkMO) ANd (6007=6007 | 4 months
xOCT) And 2390 In (sEleCT (ChaR(113)+ChaR(113)+ChaR(122)+ChaR(107)+ChaR(113)+(sEleCT (cAse whEN (2390=2390) tHeN ChaR(49) ElSE ChaR(48) eND))+ChaR(113)+ChaR(120)+ChaR(98)+ChaR(122)+ChaR(113))) And (5627=5627 | 4 months
xOCT) aNd 4927=(sElEct uppEr(XmltYPe(ChR(60)||ChR(58)||ChR(113)||ChR(113)||ChR(122)||ChR(107)||ChR(113)||(sElEct (caSe WHeN (4927=4927) thEN 1 ElSe 0 ENd) FroM duAl)||ChR(113)||ChR(120)||ChR(98)||ChR(122)||ChR(113)||ChR(62))) FroM duAl) aNd (2640=2640 | 4 months
xOCT) ANd 6185=caSt((cHr(113)||cHr(113)||cHr(122)||cHr(107)||cHr(113))||(seLEct (CasE WHEn (6185=6185) thEN 1 ELse 0 End))::TEXt||(cHr(113)||cHr(120)||cHr(98)||cHr(122)||cHr(113)) aS numErIC) ANd (1573=1573 | 4 months
xOCT) ANd 7700=2456 ANd (8159=8159 | 4 months
xOCT) And ExtractvaLuE(3620,CONcAT(0x5c,0x71717a6b71,(sELect (ELt(3620=3620,1))),0x7178627a71)) And (2282=2282 | 4 months
xOCT | 4 months
xOCT;sElECt DBMS PIPE.RecEIVE meSsage(CHr(105)||CHr(84)||CHr(67)||CHr(73),5) frOm DuaL-- | 4 months
xOCT;selECt pg sLeEP(5)-- | 4 months
xOCT;WAITFOR DELAY '0:0:5'-- | 4 months
xOCT And (sELECt 2192 froM (sELECt(sLeep(5)))fkMO) | 4 months
xOCT aND 1587=8864-- ymRx | 4 months
xOCT And 2251=7767 | 4 months
xOCT aND 2390 In (SeLect (CHAr(113)+CHAr(113)+CHAr(122)+CHAr(107)+CHAr(113)+(SeLect (Case When (2390=2390) tHen CHAr(49) elSe CHAr(48) eND))+CHAr(113)+CHAr(120)+CHAr(98)+CHAr(122)+CHAr(113)))-- XaWl | 4 months
xOCT aND 2390 iN (sELect (ChAr(113)+ChAr(113)+ChAr(122)+ChAr(107)+ChAr(113)+(sELect (CASe WHEn (2390=2390) THen ChAr(49) eLSE ChAr(48) ENd))+ChAr(113)+ChAr(120)+ChAr(98)+ChAr(122)+ChAr(113))) | 4 months
xOCT AnD 4927=(SELECt UpPer(xMltYpE(Chr(60)||Chr(58)||Chr(113)||Chr(113)||Chr(122)||Chr(107)||Chr(113)||(SELECt (cASE WHEn (4927=4927) tHen 1 eLsE 0 eND) From DuaL)||Chr(113)||Chr(120)||Chr(98)||Chr(122)||Chr(113)||Chr(62))) From DuaL)-- VqHr | 4 months
xOCT And 4927=(seLECT UppER(xmlTyPe(CHr(60)||CHr(58)||CHr(113)||CHr(113)||CHr(122)||CHr(107)||CHr(113)||(seLECT (CaSe wheN (4927=4927) tHeN 1 ElsE 0 End) fRom duAL)||CHr(113)||CHr(120)||CHr(98)||CHr(122)||CHr(113)||CHr(62))) fRom duAL) | 4 months
xOCT aNd 6185=CaSt((chR(113)||chR(113)||chR(122)||chR(107)||chR(113))||(SeLECt (CASe WHeN (6185=6185) thEn 1 ELsE 0 ENd))::Text||(chR(113)||chR(120)||chR(98)||chR(122)||chR(113)) aS nuMeriC)-- DqYm | 4 months
xOCT AnD 6185=caSt((Chr(113)||Chr(113)||Chr(122)||Chr(107)||Chr(113))||(sELEcT (CaSe wHen (6185=6185) thEn 1 ELsE 0 enD))::TeXt||(Chr(113)||Chr(120)||Chr(98)||Chr(122)||Chr(113)) aS nUmERIc) | 4 months
xOCT ANd EXtRACtVAluE(3620,COnCAt(0x5c,0x71717a6b71,(SELeCt (Elt(3620=3620,1))),0x7178627a71))-- YixG | 4 months
xOCT ANd extRACtVALUe(3620,cONCat(0x5c,0x71717a6b71,(SeleCt (Elt(3620=3620,1))),0x7178627a71)) | 4 months
Yagate Kimi ni Naru | 4 years
Yahari | 4 months
Yahari Ore No Seishun Love Come Wa Machigatteiru | 9 months
Yakitate!! Japan | 2 years
Yakusoku no Nanaya Matsuri | 5 years
Yakusoku no Neverland | 5 months
Yakusoku No Neverland | 3 years
Yamada-kun to 7-nin no Majo | 7 years
Yamada-kun to Lv999 no Koi wo Suru | 9 months
Yamakoshi Mura no Mari to Sanbiki no Koinu | 5 years
Yamikin Ushijima-kun | 4 years
Yami Shibai 9 | 2 years
Yasashii Lion | 7 years
Yatogame-chan Kansatsu Nikki Nisatsume | 4 years
Yes! Precure 5 | 1 decade
Yesterday wo Utatte | 2 years
Yes ! Precure 5 GoGo ! | 6 years
Yoake Tsugeru Lu no Uta | Lu Over the Wall | 2 years
yofukashi no uta | 1 year
Yojouhan Shinwa Taikei | 1 month
Yojouhan Time Machine Blues | 1 year
Yokohama Kaidashi Kikou - Quiet Country Cafe | 2 years
Yokohama Kaidashi Kikou | 2 years
Yokoyama Mitsuteru Sangokushi | 1 decade
Yona Yona Penguin | 1 decade
Yoru no Kurage wa Oyogenai | 5 days
Yoru wa Mijikashi Arukeyo Otome | 5 years
You are umasou da na | 6 years
Youjo Senki | 2 years
Youkai Apartment no Yuuga na Nichijou | 5 years
Youkai Watch | 9 months
Youkai Watch Jam: Youkai Gakuen Y - N to no Souguu | 3 years
Youkai Watch! | 9 months
Youkai Watch | 3 years
Youkai Watch Jam | 1 year
Youkai Watch Monge Selection Zura | 8 years
Youkai Watch Shadowside | 3 years
Youkoso Jitsuryoku Shijou Shugi no Kyoushitsu e | 4 weeks
youkosojitsuryokushijoushuginokyoushitsue3rd Season | 3 weeks
Young Animator Training Project | 8 years
Young Black Jack | 8 years
Your voice | 4 months
Yowai 5000-nen no Soushoku Dragon, Iwarenaki Jaryuu Nintei | 9 months
Yowamushi Pedal | 1 year
Yozakura-san Chi no Daisakusen | 6 days
Yu-Gi-Oh! Duel Monsters | 11 months
Yu-Gi-Oh! Duel Monsters Remaster Duelist Kingdom | 8 years
Yu-Gi-Oh! Go Rush!! | 2 years
Yu-Gi-Oh! SEVENS | 2 years
Yu-Gi-Oh! 5D's | 9 years
Yu-Gi-Oh! ARC-V | 7 months
Yu-Gi-Oh! Duel Monsters GX | 1 decade
Yu-Gi-Oh! VRAINS | 6 years
Yu-Gi-Oh! ZEXAL | 1 decade
Yubisaki to Renren | 3 weeks
Yuki no Taiyou | 9 years
Yumeiro Patissiere Special Professional | 1 decade
Yumekui Merry | 1 decade
Yumemiru Danshi wa Genjitsushugisha | 7 months
Yuri!!! on Ice | 5 years
Yurikuma Arashi | 1 year
Yuru Camp (Live action) | 6 months
Yuru Camp | 9 months
Yuru Camp Movie | 1 year
Yuru Camp S2 | 5 months
Yuru Camp S3 | 2 days
Yuru Yuri | 5 years
Yuru Yuri OVA | 5 years
Yuru Yuri S2 | 5 years
Yuru Yuri San Hai! | 5 years
Yuukai Anna | 5 years
Yuuki Bakuhatsu Bang Bravern | 3 weeks
Yuuki Yuuna Wa Yuusha Dearu | 5 years
Yuuki Yuuna Wa Yuusha De Aru Dai-Mankai No | 2 years
Yuukoku no Moriarty | 9 months
Yuusha, Yamemasu | 1 year
Yuusha-Ou GaoGaiGar | 6 years
Yuusha-Ou GaoGaiGar Final | 6 years
Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita | 9 years
Yuusha Tokkyuu Might Gaine | 5 years
Yuzuki-san Chi no Yonkyoudai. | 4 months
Yu Yu Hakusho | 3 years
Zankyou No Teroru | 3 years
ZEGAPAIN | 5 years
zero | 4 months
Zero kara Hajimeru Mahou no Sho | 4 years
Zero no Tsukaima | 5 years
Zetman | 4 years
Zetsuen No Tempest | 5 years
Zettai Shougeki Platonic Heart | 1 decade
Zettai Bouei Leviathan | 1 decade
Zipang | 5 years
Zoids Wild | 4 years
Zoku Owarimonogatari | 3 years
Zoku Sayonara Zetsubousensei | 6 years
Zom | 7 months
Zom 100: Bucket List of the Dead | 9 months
Zom 100: Zombie ni Naru made ni Shitai 100 no Koto | 4 months
Zombieland Saga | 9 months
Zonmi-chan | 7 years
ztyu'aiktIv<'">rWGoXw | 1 month
ztyu(,,,'".,)( | 1 month
ztyu | 1 month
Zutto Mae kara Suki Deshita. Kokuhaku Jikkou Iinkai | 3 years
zutto suki datta | 1 month
zzzzz | 1 week
Anyme lyrics (lrc).zip | 2 MB | 5 years
Caption2Ass PCR With Gaiji List Updated.rar | 640 KB | 1 decade
Caption2Ass With Gaiji List Updated.rar | 652 KB | 1 decade
Japanese Oldies Shounen Shoujo Seinen Anime Subtitles.rar | 132 MB | 1 decade
Japanese Shounen Shoujo Seinen Anime Subtitles.rar | 132 MB | 7 years
Jpsubbers.xyz-Archive.zip | 297 MB | 1 year

Sign in to upload files